"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ClientProvider = exports.ClientContext = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const gql_client_1 = require("@tribeplatform/gql-client");
const getTokens_1 = require("./lib/getTokens");
exports.ClientContext = (0, react_1.createContext)({
    client: null,
    ready: undefined,
    boot: null,
    config: null,
});
const SSR = typeof window === 'undefined';
const ClientProvider = ({ children, config, autoBoot = true, onTokenUpdate, }) => {
    var _a, _b, _c;
    const { accessToken, baseUrl } = config;
    const loadingRef = (0, react_1.useRef)(false);
    let graphqlUrl = baseUrl;
    if (!graphqlUrl && typeof process !== 'undefined') {
        graphqlUrl = (_a = process === null || process === void 0 ? void 0 : process.env) === null || _a === void 0 ? void 0 : _a.TRIBE_GQL_ENDPOINT;
    }
    const [client, setClient] = (0, react_1.useState)(new gql_client_1.TribeClient({
        accessToken,
        graphqlUrl,
        onError: config.onError,
        onEvent: config.onEvent,
        notifyOnTokenExpiration: !SSR,
    }));
    const ready = !!((_c = (_b = client) === null || _b === void 0 ? void 0 : _b.client) === null || _c === void 0 ? void 0 : _c.accessToken);
    const update = (0, react_1.useCallback)(async (config) => {
        const res = await (0, getTokens_1.getTokens)(config);
        const { client: newClient } = res;
        setClient(newClient);
        loadingRef.current = false;
        return res;
    }, [setClient, loadingRef]);
    (0, react_1.useEffect)(() => {
        if (autoBoot && !loadingRef.current && !ready) {
            loadingRef.current = true;
            update(config);
        }
    }, [loadingRef, update, client, ready, config, autoBoot]);
    const boot = () => {
        update(config);
    };
    return ((0, jsx_runtime_1.jsx)(exports.ClientContext.Provider, { value: { client, ready, boot, config, onTokenUpdate }, children: children }, void 0));
};
exports.ClientProvider = ClientProvider;
//# sourceMappingURL=ClientProvider.js.map