"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MediaModal = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const clsx_1 = __importDefault(require("clsx"));
const filesize_1 = __importDefault(require("filesize"));
const react_responsive_carousel_1 = require("react-responsive-carousel");
const ArrowLeftLineIcon_js_1 = __importDefault(require("remixicon-react/ArrowLeftLineIcon.js"));
const ArrowRightLineIcon_js_1 = __importDefault(require("remixicon-react/ArrowRightLineIcon.js"));
const CloseLineIcon_js_1 = __importDefault(require("remixicon-react/CloseLineIcon.js"));
const DownloadCloud2LineIcon_js_1 = __importDefault(require("remixicon-react/DownloadCloud2LineIcon.js"));
const Button_1 = require("@tribeplatform/react-ui-kit/Button");
const Modal_1 = require("@tribeplatform/react-ui-kit/Modal");
const MediaPreview_js_1 = require("./MediaPreview.js");
const utils_js_1 = require("./utils.js");
const MediaModal = ({ slides, isVisible = false, onClose, activeMediaIndex = 0, }) => {
    const cache = (0, react_1.useRef)({});
    const [downloading, setDownloading] = (0, react_1.useState)(false);
    const [currentIndex, setCurrentIndex] = (0, react_1.useState)(activeMediaIndex);
    const slide = slides[currentIndex];
    const length = slides === null || slides === void 0 ? void 0 : slides.length;
    const isPreviousButtonEnabled = currentIndex > 0;
    const isNextButtonEnabled = currentIndex < length - 1;
    const handleDownload = async () => {
        const slide = slides[currentIndex];
        if (!(slide === null || slide === void 0 ? void 0 : slide.url) && !(slide === null || slide === void 0 ? void 0 : slide.downloadUrl))
            return;
        setDownloading(true);
        if (slide.downloadUrl) {
            await (0, utils_js_1.downloadFile)(slide.downloadUrl, slide.name);
        }
        else {
            await (0, utils_js_1.downloadFile)(slide.url);
        }
        setDownloading(false);
    };
    (0, react_1.useEffect)(() => {
        return () => {
            // clear the cache on unmount
            cache.current = {};
        };
    }, []);
    (0, react_1.useEffect)(() => {
        setCurrentIndex(activeMediaIndex);
    }, [activeMediaIndex]);
    return ((0, jsx_runtime_1.jsxs)(Modal_1.Modal, { size: "full", open: isVisible, onClose: onClose, className: "flex-col flex", children: [(0, jsx_runtime_1.jsxs)("div", { className: "px-4 py-5 sm:px-6 flex items-center justify-end border-b border-surface-200/50 space-x-1", children: [(0, jsx_runtime_1.jsxs)("div", { className: "overflow-hidden flex-grow", children: [slide.name && (0, jsx_runtime_1.jsx)("p", { className: "truncate", children: slide.name }, void 0), slide.size && ((0, jsx_runtime_1.jsx)("p", { className: "text-basicSurface-500", children: (0, filesize_1.default)(slide.size) }, void 0))] }, void 0), (0, jsx_runtime_1.jsxs)("div", { className: "flex", children: [(0, jsx_runtime_1.jsx)(Button_1.Button, { size: "md", className: "hover:bg-transparent", variant: "basic", disabled: downloading, loading: downloading, leadingIcon: (0, jsx_runtime_1.jsx)(DownloadCloud2LineIcon_js_1.default, {}, void 0), onClick: handleDownload }, void 0), (0, jsx_runtime_1.jsx)(Button_1.Button, { size: "md", className: "hover:bg-transparent", variant: "basic", onClick: onClose, leadingIcon: (0, jsx_runtime_1.jsx)(CloseLineIcon_js_1.default, {}, void 0) }, void 0)] }, void 0)] }, void 0), (0, jsx_runtime_1.jsxs)(Modal_1.Modal.Content, { className: (0, clsx_1.default)('flex items-center justify-center space-x-3 py-0', length > 1 ? 'px-3' : 'px-0 sm:p-0'), children: [length > 1 && ((0, jsx_runtime_1.jsx)(Button_1.Button, { variant: "outline", rounded: true, onClick: () => isPreviousButtonEnabled && setCurrentIndex(currentIndex - 1), disabled: !isPreviousButtonEnabled, leadingIcon: (0, jsx_runtime_1.jsx)(ArrowLeftLineIcon_js_1.default, {}, void 0) }, void 0)), (0, jsx_runtime_1.jsx)("div", { className: "max-h-screen flex-1", children: (0, jsx_runtime_1.jsx)(react_responsive_carousel_1.Carousel, { selectedItem: currentIndex, dynamicHeight: false, showStatus: false, infiniteLoop: false, showThumbs: false, showIndicators: false, showArrows: false, transitionTime: 200, useKeyboardArrows: true, children: slides.map((slide, index) => {
                                if (cache.current[index] || index === currentIndex) {
                                    cache.current[currentIndex] = true;
                                    // Other types like video will be added later.
                                    return ((0, jsx_runtime_1.jsx)(MediaPreview_js_1.MediaPreview, { media: slide, isActive: currentIndex === index }, slide.id || slide.name));
                                }
                                return ((0, jsx_runtime_1.jsx)("div", { className: "flex items-center justify-center" }, slide.id || slide.name));
                            }) }, void 0) }, void 0), length > 1 && ((0, jsx_runtime_1.jsx)(Button_1.Button, { variant: "outline", rounded: true, onClick: () => isNextButtonEnabled && setCurrentIndex(currentIndex + 1), disabled: !isNextButtonEnabled, leadingIcon: (0, jsx_runtime_1.jsx)(ArrowRightLineIcon_js_1.default, {}, void 0) }, void 0))] }, void 0)] }, void 0));
};
exports.MediaModal = MediaModal;
//# sourceMappingURL=MediaModal.js.map