"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useInstallApp = void 0;
const lib_1 = require("../../lib");
const useTribeClient_1 = require("../../useTribeClient");
const keys_1 = require("../../utils/keys");
const useInstallApp = (options) => {
    const { useMutationOptions, fields = 'basic' } = options || {};
    const { client } = (0, useTribeClient_1.useTribeClient)();
    const queryClient = (0, lib_1.useQueryClient)();
    return (0, lib_1.useMutation)(input => client.app.install(input, fields), {
        onMutate: variables => {
            const appKey = (0, keys_1.getAppKey)({ variables: { id: variables.appId } });
            queryClient.setQueriesData(appKey, old => ({
                ...old,
                installed: true,
            }));
            const appsKey = (0, keys_1.getAppsKey)();
            queryClient.setQueriesData(appsKey, old => {
                var _a, _b;
                return ({
                    ...old,
                    edges: (_a = old === null || old === void 0 ? void 0 : old.edges) === null || _a === void 0 ? void 0 : _a.map(edge => ({
                        ...edge,
                        node: {
                            ...edge.node,
                            installed: edge.node.id === variables.appId ? true : edge.node.installed,
                        },
                    })),
                    nodes: (_b = old === null || old === void 0 ? void 0 : old.nodes) === null || _b === void 0 ? void 0 : _b.map(node => ({
                        ...node,
                        installed: node.id === variables.appId ? true : node.installed,
                    })),
                });
            });
        },
        onSettled: (data, error, variables) => {
            const appKey = (0, keys_1.getAppKey)({ variables: { id: variables.appId } });
            queryClient.invalidateQueries(appKey);
            const appsKey = (0, keys_1.getAppsKey)();
            queryClient.invalidateQueries(appsKey);
            const appInstallationsKey = (0, keys_1.getAppInstallationsKey)();
            queryClient.invalidateQueries(appInstallationsKey);
        },
        ...useMutationOptions,
    });
};
exports.useInstallApp = useInstallApp;
//# sourceMappingURL=useInstallApp.js.map