"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useLogin = void 0;
const react_1 = require("react");
const lib_1 = require("../../lib");
const useTribeClient_1 = require("../../useTribeClient");
const keys_1 = require("../../utils/keys");
const useLogin = () => {
    const queryClient = (0, lib_1.useQueryClient)();
    const { client } = (0, useTribeClient_1.useTribeClient)();
    const [isLoading, setLoading] = (0, react_1.useState)(false);
    const authTokenKey = (0, keys_1.getAuthTokenKey)();
    const login = (0, react_1.useCallback)(async ({ variables, willReload = false, useQueryOptions, fields = 'default', }) => {
        const loginKey = (0, keys_1.getLoginKey)({ variables, fields });
        setLoading(true);
        try {
            const data = await queryClient.fetchQuery(loginKey, () => client === null || client === void 0 ? void 0 : client.auth.login(variables, fields), useQueryOptions);
            // Do not set loading to false and update cache if we're reloading the page right after.
            if (!willReload) {
                queryClient.setQueriesData(authTokenKey, data);
                setLoading(false);
            }
            return data;
        }
        catch (error) {
            setLoading(false);
            throw error;
        }
    }, [authTokenKey, client === null || client === void 0 ? void 0 : client.auth, queryClient]);
    return {
        login,
        isLoading,
    };
};
exports.useLogin = useLogin;
//# sourceMappingURL=useLogin.js.map