"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useUpdateJwtSso = void 0;
const types_1 = require("@tribeplatform/gql-client/types");
const lib_1 = require("../../lib");
const useTribeClient_1 = require("../../useTribeClient");
const keys_1 = require("../../utils/keys");
const useUpdateJwtSso = (options) => {
    const { useMutationOptions } = options || {};
    const { client } = (0, useTribeClient_1.useTribeClient)();
    const queryClient = (0, lib_1.useQueryClient)();
    const ssosKey = (0, keys_1.getSsosKey)();
    return (0, lib_1.useMutation)((input) => client.auth.updateJwtSso(input), {
        onMutate: async (updatedJwtSso) => {
            await queryClient.cancelQueries(ssosKey);
            const snapshot = queryClient.getQueryData(ssosKey);
            queryClient.setQueriesData(ssosKey, old => [
                ...old === null || old === void 0 ? void 0 : old.filter(sso => sso.type !== types_1.SsoType.jwt),
                { ...old === null || old === void 0 ? void 0 : old.find(sso => sso.type === types_1.SsoType.jwt), ...updatedJwtSso },
            ]);
            return { snapshot };
        },
        onSuccess: updatedJwtSso => {
            queryClient.setQueriesData(ssosKey, old => [
                ...old === null || old === void 0 ? void 0 : old.filter(sso => sso.type !== types_1.SsoType.jwt),
                { ...old === null || old === void 0 ? void 0 : old.find(sso => sso.type === types_1.SsoType.jwt), ...updatedJwtSso },
            ]);
        },
        onError: (_, __, context) => {
            queryClient.setQueriesData(ssosKey, context.snapshot);
        },
        onSettled: () => {
            queryClient.invalidateQueries(ssosKey);
        },
        ...useMutationOptions,
    });
};
exports.useUpdateJwtSso = useUpdateJwtSso;
//# sourceMappingURL=useUpdateJwtSso.js.map