"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useCachedAuthMember = void 0;
const lodash_1 = require("lodash");
const lib_1 = require("../../lib");
const keys_1 = require("../../utils/keys");
const findAuthMemberInAuthToken = (queryClient) => {
    const queries = queryClient.getQueriesData({
        queryKey: (0, keys_1.getAuthTokenKey)(),
    });
    let authMember;
    queries === null || queries === void 0 ? void 0 : queries.forEach(query => {
        const authToken = query === null || query === void 0 ? void 0 : query[1];
        authMember = {
            ...authMember,
            ...authToken === null || authToken === void 0 ? void 0 : authToken.member,
        };
    });
    return authMember;
};
const findAuthMember = (queryClient) => {
    const queries = queryClient.getQueriesData({
        queryKey: (0, keys_1.getAuthMemberKey)(),
    });
    let authMember;
    queries === null || queries === void 0 ? void 0 : queries.forEach(query => {
        const data = query === null || query === void 0 ? void 0 : query[1];
        authMember = {
            ...authMember,
            ...data,
        };
    });
    return authMember;
};
const useCachedAuthMember = () => {
    const queryClient = (0, lib_1.useQueryClient)();
    const authMember = {
        ...findAuthMember(queryClient),
        ...findAuthMemberInAuthToken(queryClient),
    };
    if (!(0, lodash_1.isEmpty)(authMember))
        return authMember;
};
exports.useCachedAuthMember = useCachedAuthMember;
//# sourceMappingURL=useCachedAuthMember.js.map