"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useCachedNetwork = exports.navigationSlateReducer = exports.authTokenUpdater = exports.networkUpdater = void 0;
const lodash_1 = require("lodash");
const lib_1 = require("../../lib");
const keys_1 = require("../../utils/keys");
const networkUpdater = newNetwork => old => {
    let network = newNetwork;
    if (typeof newNetwork === 'function') {
        network = newNetwork(old);
    }
    return {
        ...old,
        ...network,
    };
};
exports.networkUpdater = networkUpdater;
const authTokenUpdater = newAuthToken => old => {
    return {
        ...old,
        ...newAuthToken,
        network: (0, exports.networkUpdater)(newAuthToken === null || newAuthToken === void 0 ? void 0 : newAuthToken.network)(old === null || old === void 0 ? void 0 : old.network),
    };
};
exports.authTokenUpdater = authTokenUpdater;
const navigationSlateReducer = (network, updatedSlateIds, slates) => Object.keys(network.navigationSlates)
    .map(key => {
    const slate = network.navigationSlates[key];
    if (!slate)
        return undefined;
    if (updatedSlateIds.includes(slate.id)) {
        return { [key]: slates.find(s => s.id === slate.id) };
    }
    return { [key]: slate };
})
    .reduce((preValue, value) => ({ ...preValue, ...value }), network.navigationSlates);
exports.navigationSlateReducer = navigationSlateReducer;
const findNetwork = (queryClient) => {
    const queries = queryClient.getQueriesData({
        queryKey: (0, keys_1.getNetworkKey)(),
    });
    let network;
    queries === null || queries === void 0 ? void 0 : queries.forEach(query => {
        const data = query === null || query === void 0 ? void 0 : query[1];
        network = {
            ...network,
            ...data,
        };
    });
    return network;
};
const findNetworkInAuthToken = (queryClient) => {
    const queries = queryClient.getQueriesData({
        queryKey: (0, keys_1.getAuthTokenKey)(),
    });
    let network;
    queries === null || queries === void 0 ? void 0 : queries.forEach(query => {
        const authToken = query === null || query === void 0 ? void 0 : query[1];
        network = {
            ...network,
            ...authToken === null || authToken === void 0 ? void 0 : authToken.network,
        };
    });
    return network;
};
const useCachedNetwork = () => {
    const queryClient = (0, lib_1.useQueryClient)();
    const network = {
        ...findNetwork(queryClient),
        ...findNetworkInAuthToken(queryClient),
    };
    if (!(0, lodash_1.isEmpty)(network))
        return network;
};
exports.useCachedNetwork = useCachedNetwork;
//# sourceMappingURL=useCachedNetwork.js.map