"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useUpdateMember = void 0;
const hooks_1 = require("@tribeplatform/react-sdk/hooks");
const lib_1 = require("../../lib");
const useTribeClient_1 = require("../../useTribeClient");
const keys_1 = require("../../utils/keys");
const authToken_keys_1 = require("../../utils/keys/authToken.keys");
const useAuthMember_1 = require("../auth/useAuthMember");
const useUpdateMember = (options) => {
    const { useMutationOptions, fields = 'default' } = options || {};
    const { client } = (0, useTribeClient_1.useTribeClient)();
    const queryClient = (0, lib_1.useQueryClient)();
    const { data: authMember } = (0, useAuthMember_1.useAuthMember)();
    return (0, lib_1.useMutation)((input) => client.members.update(input, fields), {
        onMutate: async (newMember) => {
            const memberKey = (0, keys_1.getMemberKey)({ variables: { id: newMember.id } });
            await queryClient.cancelQueries(memberKey);
            const snapshot = (0, hooks_1.getCachedMember)(newMember.id, queryClient);
            queryClient.setQueriesData(memberKey, old => ({
                ...old,
                ...newMember,
            }));
            return { snapshot };
        },
        onSuccess: (updatedMember, vars, context) => {
            var _a;
            const memberKey = (0, keys_1.getMemberKey)({ variables: { id: updatedMember.id } });
            queryClient.setQueriesData(memberKey, oldMember => ({
                ...oldMember,
                ...updatedMember,
            }));
            if (authMember.id === updatedMember.id) {
                queryClient.invalidateQueries((0, authToken_keys_1.getAuthMemberKey)());
            }
            (_a = useMutationOptions === null || useMutationOptions === void 0 ? void 0 : useMutationOptions.onSuccess) === null || _a === void 0 ? void 0 : _a.call(useMutationOptions, updatedMember, vars, context);
        },
        onError: (err, newMember, context) => {
            var _a;
            const memberKey = (0, keys_1.getMemberKey)({ variables: { id: newMember.id } });
            queryClient.setQueriesData(memberKey, context.snapshot);
            queryClient.invalidateQueries(memberKey);
            (_a = useMutationOptions === null || useMutationOptions === void 0 ? void 0 : useMutationOptions.onError) === null || _a === void 0 ? void 0 : _a.call(useMutationOptions, err, newMember, context);
        },
        onSettled: () => {
            const membersKey = (0, keys_1.getMembersKey)();
            const authTokenKey = (0, authToken_keys_1.getAuthTokenKey)();
            queryClient.invalidateQueries(membersKey);
            queryClient.invalidateQueries(authTokenKey);
        },
        ...useMutationOptions,
    });
};
exports.useUpdateMember = useUpdateMember;
//# sourceMappingURL=useUpdateMember.js.map