"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useUpdateModerationSettings = void 0;
const lib_1 = require("../../lib");
const useTribeClient_1 = require("../../useTribeClient");
const keys_1 = require("../../utils/keys");
const useUpdateModerationSettings = (options) => {
    const { useMutationOptions } = options || {};
    const { client } = (0, useTribeClient_1.useTribeClient)();
    const queryClient = (0, lib_1.useQueryClient)();
    const moderationSettingsKey = (0, keys_1.getModerationSettingsKey)();
    return (0, lib_1.useMutation)(variables => client.moderation.updateSettings(variables), {
        onMutate: async (newModerationSettings) => {
            await queryClient.cancelQueries(moderationSettingsKey);
            const snapshot = queryClient.getQueryData(moderationSettingsKey);
            queryClient.setQueriesData(moderationSettingsKey, old => {
                return {
                    ...old,
                    ...newModerationSettings,
                };
            });
            return { snapshot };
        },
        onError: (err, newNetworkSettings, context) => {
            // revert back the optimistic response
            queryClient.setQueriesData(moderationSettingsKey, context.snapshot);
        },
        onSettled: () => {
            // invalidate to refetch again
            queryClient.invalidateQueries(moderationSettingsKey);
        },
        ...useMutationOptions,
    });
};
exports.useUpdateModerationSettings = useUpdateModerationSettings;
//# sourceMappingURL=useUpdateModerationSettings.js.map