"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useUpdateNetwork = void 0;
const hooks_1 = require("@tribeplatform/react-sdk/hooks");
const lib_1 = require("../../lib");
const useTribeClient_1 = require("../../useTribeClient");
const keys_1 = require("../../utils/keys");
const useUpdateNetwork = (options) => {
    const { useMutationOptions, fields } = options || {};
    const { client } = (0, useTribeClient_1.useTribeClient)();
    const queryClient = (0, lib_1.useQueryClient)();
    const networkKey = (0, keys_1.getNetworkKey)();
    const authTokenKey = (0, keys_1.getAuthTokenKey)();
    const networkSnapshot = (0, hooks_1.useCachedNetwork)();
    return (0, lib_1.useMutation)((input) => client.network.update(input, fields), {
        onMutate: async (variables) => {
            // Cancel any outgoing refetches (so they don't overwrite our optimistic update)
            await queryClient.cancelQueries(networkKey);
            // Snapshot the previous value
            const snapshot = networkSnapshot;
            // Optimistically update to the new value
            // We are removing navigationSlates here because of type conflict
            const networkInput = variables.input;
            const networkUpdater = (old) => ({
                ...old,
                ...networkInput,
                navigationSlates: old === null || old === void 0 ? void 0 : old.navigationSlates,
                landingPages: null,
            });
            queryClient.setQueriesData(networkKey, networkUpdater);
            // TODO: find a way to automatically update the network
            queryClient.setQueriesData(authTokenKey, old => ({
                ...old,
                network: networkUpdater(old.network),
            }));
            // Return a context object with the snapshotted value
            return { snapshot };
        },
        onSuccess: data => {
            queryClient.setQueriesData(networkKey, oldData => ({
                ...oldData,
                ...data,
            }));
        },
        onError: (err, newNetwork, context) => {
            // revert back the optimistic response
            queryClient.setQueriesData(networkKey, context.snapshot);
        },
        onSettled: () => {
            // Re-fetch the network
            queryClient.invalidateQueries(networkKey);
            // Re-fetch the auth tokens
            queryClient.invalidateQueries(authTokenKey);
        },
        ...useMutationOptions,
    });
};
exports.useUpdateNetwork = useUpdateNetwork;
//# sourceMappingURL=useUpdateNetwork.js.map