"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useUpsertTheme = void 0;
const lib_1 = require("../../lib");
const useTribeClient_1 = require("../../useTribeClient");
const keys_1 = require("../../utils/keys");
const cache_1 = require("../cache");
const useUpsertTheme = (options) => {
    const { useMutationOptions, fields } = options || {};
    const { client } = (0, useTribeClient_1.useTribeClient)();
    const queryClient = (0, lib_1.useQueryClient)();
    const networkKey = (0, keys_1.getNetworkKey)();
    const authTokenKey = (0, keys_1.getAuthTokenKey)();
    const networkSnapshot = (0, cache_1.useCachedNetwork)();
    return (0, lib_1.useMutation)((input) => client.theme.upsert(input, fields), {
        onMutate: async (newTheme) => {
            var _a;
            const snapshot = networkSnapshot;
            if ((_a = newTheme.input) === null || _a === void 0 ? void 0 : _a.active) {
                await queryClient.cancelQueries(networkKey);
                queryClient.setQueriesData(networkKey, (0, cache_1.networkUpdater)({ activeTheme: newTheme.input }));
                queryClient.setQueriesData(authTokenKey, (0, cache_1.authTokenUpdater)({
                    network: { activeTheme: newTheme.input },
                }));
            }
            return { snapshot };
        },
        onSuccess: newTheme => {
            queryClient.setQueriesData(authTokenKey, (0, cache_1.authTokenUpdater)({
                network: { activeTheme: newTheme },
            }));
        },
        onError: (err, newTheme, context) => {
            queryClient.setQueriesData(networkKey, context.snapshot);
            queryClient.setQueriesData(authTokenKey, (0, cache_1.authTokenUpdater)({ network: context.snapshot }));
        },
        onSettled: () => {
            queryClient.invalidateQueries(networkKey);
            queryClient.invalidateQueries(authTokenKey);
        },
        ...useMutationOptions,
    });
};
exports.useUpsertTheme = useUpsertTheme;
//# sourceMappingURL=useUpsertTheme.js.map