"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useReadNotification = void 0;
const lib_1 = require("../../lib");
const useTribeClient_1 = require("../../useTribeClient");
const keys_1 = require("../../utils/keys");
const useReadNotification = (options) => {
    const { useMutationOptions } = options || {};
    const { client } = (0, useTribeClient_1.useTribeClient)();
    const queryClient = (0, lib_1.useQueryClient)();
    return (0, lib_1.useMutation)(input => client.notifications.readNotification(input), {
        onMutate: variables => {
            const notificationsKey = (0, keys_1.getNotificationsKey)();
            queryClient.setQueriesData(notificationsKey, input => {
                const updatedInput = {
                    ...input,
                    pages: input.pages.map(page => ({
                        ...page,
                        nodes: page.nodes.map(notification => ({
                            ...notification,
                            read: notification.id === variables.notificationId
                                ? true
                                : notification.read,
                        })),
                        edges: page.edges.map(edge => ({
                            ...edge,
                            node: {
                                ...edge.node,
                                read: edge.node.id === variables.notificationId
                                    ? true
                                    : edge.node.read,
                            },
                        })),
                    })),
                };
                return updatedInput;
            });
        },
        onSettled: () => {
            const notificationsKey = (0, keys_1.getNotificationsKey)();
            queryClient.invalidateQueries(notificationsKey);
            const notificationsCountKey = (0, keys_1.getNotificationsCountKey)();
            queryClient.invalidateQueries(notificationsCountKey);
        },
        ...useMutationOptions,
    });
};
exports.useReadNotification = useReadNotification;
//# sourceMappingURL=useReadNotification.js.map