"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useUpdateMemberPostNotificationSettings = void 0;
const lib_1 = require("../../lib");
const useTribeClient_1 = require("../../useTribeClient");
const keys_1 = require("../../utils/keys");
const useCachedPost_1 = require("../cache/useCachedPost");
const filters_1 = require("../posts/filters");
const updater = (memberPostNotificationSettingsEnabled) => (oldPost) => ({
    ...oldPost,
    authMemberProps: {
        ...oldPost.authMemberProps,
        memberPostNotificationSettingsEnabled,
    },
});
const useUpdateMemberPostNotificationSettings = (options) => {
    const { useMutationOptions } = options || {};
    const { client } = (0, useTribeClient_1.useTribeClient)();
    const queryClient = (0, lib_1.useQueryClient)();
    return (0, lib_1.useMutation)((input) => client.notifications.updateMemberPostNotificationSettings(input), {
        onMutate: async (newMemberPostNotificationSettings) => {
            const { postId, input } = newMemberPostNotificationSettings;
            const memberPostNotificationSettingsKey = (0, keys_1.getMemberPostNotificationSettingsKey)({
                variables: {
                    postId: newMemberPostNotificationSettings === null || newMemberPostNotificationSettings === void 0 ? void 0 : newMemberPostNotificationSettings.postId,
                },
            });
            await queryClient.cancelQueries(memberPostNotificationSettingsKey);
            const snapshot = queryClient.getQueryData(memberPostNotificationSettingsKey);
            queryClient.setQueriesData(memberPostNotificationSettingsKey, oldMemberPostNotificationSettings => ({
                ...oldMemberPostNotificationSettings,
                ...newMemberPostNotificationSettings,
            }));
            const postKey = {
                queryKey: (0, keys_1.getPostKey)({ variables: { id: postId } }),
                exact: false,
                active: true,
            };
            const postSnapshot = queryClient.getQueryData(postKey);
            if (postSnapshot) {
                queryClient.setQueriesData(postKey, updater(input.enabled));
            }
            const pinnedPostsSnapshot = queryClient.getQueriesData(filters_1.pinnedPostsFilter);
            if (pinnedPostsSnapshot) {
                queryClient.setQueriesData(filters_1.pinnedPostsFilter, oldPosts => oldPosts.map((0, useCachedPost_1.infinitePostArrayUpdater)(postId, updater(input.enabled), true)));
            }
            // take a snapshot from all matched posts queries
            const postsSnapshots = queryClient.getQueriesData(filters_1.postsQueryFilter);
            // update posts and replies within the found post everywhere (posts and the feed queries)
            queryClient.setQueriesData(filters_1.postsQueryFilter, (0, useCachedPost_1.infinitePostUpdater)(postId, updater(input.enabled), false));
            return { snapshot, postsSnapshots, pinnedPostsSnapshot, postSnapshot };
        },
        onError: (err, newMemberPostNotificationSettings, context) => {
            const { postId } = newMemberPostNotificationSettings;
            const memberPostNotificationSettingsKey = (0, keys_1.getMemberPostNotificationSettingsKey)({
                variables: {
                    postId,
                },
            });
            queryClient.invalidateQueries(memberPostNotificationSettingsKey);
            if (context.postSnapshot) {
                const postKey = (0, keys_1.getPostKey)({ variables: { id: postId } });
                queryClient.setQueriesData(postKey, context.postSnapshot);
            }
            if (context.pinnedPostsSnapshot) {
                context.pinnedPostsSnapshot.forEach(([queryKey, snapshot]) => {
                    queryClient.setQueriesData(queryKey, snapshot);
                });
            }
            if (context.postsSnapshots) {
                context.postsSnapshots.forEach(([queryKey, snapshot]) => {
                    queryClient.setQueriesData(queryKey, snapshot);
                });
            }
        },
        ...useMutationOptions,
    });
};
exports.useUpdateMemberPostNotificationSettings = useUpdateMemberPostNotificationSettings;
//# sourceMappingURL=useUpdateMemberPostNotificationSettings.js.map