"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useAddReaction = void 0;
const lib_1 = require("../../lib");
const useTribeClient_1 = require("../../useTribeClient");
const keys_1 = require("../../utils/keys");
const auth_1 = require("../auth");
const useCachedPost_1 = require("../cache/useCachedPost");
const filters_1 = require("./filters");
const useAddReaction = (options) => {
    const queryClient = (0, lib_1.useQueryClient)();
    const { useMutationOptions } = options || {};
    const { client } = (0, useTribeClient_1.useTribeClient)();
    const { data: authMember } = (0, auth_1.useAuthMember)();
    const userReaction = {
        participant: {
            ...authMember,
        },
    };
    return (0, lib_1.useMutation)((input) => client.posts.addReaction(input), {
        onMutate: async (addReactionArgs) => {
            const { reaction } = addReactionArgs.input;
            // updating the post itself
            const postKey = (0, keys_1.getPostKey)({
                variables: { id: addReactionArgs === null || addReactionArgs === void 0 ? void 0 : addReactionArgs.postId },
            });
            await queryClient.cancelQueries(postKey);
            const postSnapshot = (0, useCachedPost_1.getCachedPost)(addReactionArgs === null || addReactionArgs === void 0 ? void 0 : addReactionArgs.postId, queryClient);
            if (postSnapshot) {
                queryClient.setQueriesData(postKey, (0, useCachedPost_1.addReactionToPost)(reaction, userReaction));
            }
            // updating pinned posts
            const pinnedPostsSnapshot = queryClient.getQueriesData(filters_1.pinnedPostsFilter);
            if (pinnedPostsSnapshot) {
                queryClient.setQueriesData(filters_1.pinnedPostsFilter, oldPosts => oldPosts.map((0, useCachedPost_1.infinitePostArrayUpdater)(addReactionArgs.postId, (0, useCachedPost_1.addReactionToPost)(reaction, userReaction), true)));
            }
            // take a snapshot from all matched posts queries
            const postsSnapshots = queryClient.getQueriesData(filters_1.postsQueryFilter);
            // update posts and replies within the found post everywhere (posts and the feed queries)
            queryClient.setQueriesData(filters_1.postsQueryFilter, (0, useCachedPost_1.infinitePostUpdater)(addReactionArgs.postId, (0, useCachedPost_1.addReactionToPost)(reaction, userReaction), true));
            // updating root post if adding the reaction on a reply if no feed/posts have found
            let rootPostSnapshot;
            let rootPostKey;
            if (!(pinnedPostsSnapshot === null || pinnedPostsSnapshot === void 0 ? void 0 : pinnedPostsSnapshot.length) && !(postsSnapshots === null || postsSnapshots === void 0 ? void 0 : postsSnapshots.length)) {
                const rootPost = (0, useCachedPost_1.getCachedRootPostByReplies)(addReactionArgs.postId, queryClient);
                if (rootPost &&
                    rootPost.replies &&
                    rootPost.id !== addReactionArgs.postId) {
                    rootPostKey = (0, keys_1.getPostKey)({ variables: { id: rootPost === null || rootPost === void 0 ? void 0 : rootPost.id } });
                    rootPostSnapshot = queryClient.getQueryData(rootPostKey);
                    if (rootPostSnapshot) {
                        queryClient.setQueriesData(rootPostKey, (0, useCachedPost_1.infinitePostArrayUpdater)(addReactionArgs.postId, (0, useCachedPost_1.addReactionToPost)(reaction, userReaction), true));
                    }
                }
            }
            return [
                [postKey, postSnapshot],
                [rootPostKey, rootPostSnapshot],
                ...pinnedPostsSnapshot,
                ...postsSnapshots,
            ];
        },
        onError: (error, variables, context) => {
            context.forEach(([queryKey, snapshot]) => {
                if (queryKey) {
                    queryClient.setQueriesData(queryKey, snapshot);
                }
            });
        },
        ...useMutationOptions,
    });
};
exports.useAddReaction = useAddReaction;
//# sourceMappingURL=useAddReaction.js.map