"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useAddReply = void 0;
const lib_1 = require("../../lib");
const useTribeClient_1 = require("../../useTribeClient");
const keys_1 = require("../../utils/keys");
const useCachedPost_1 = require("../cache/useCachedPost");
const filters_1 = require("./filters");
const onAddReply = (variables, newPost, queryClient) => {
    const { postId } = variables;
    /** Add the reply to the parent post.replies query */
    const rootPostKey = (0, keys_1.getPostKey)({ variables: { id: postId } });
    const rootPostSnapshot = (0, useCachedPost_1.getCachedPost)(postId, queryClient);
    if (rootPostSnapshot) {
        queryClient.setQueriesData(rootPostKey, (0, useCachedPost_1.postRepliesUpdater)(newPost));
    }
    /**
     * Add the reply to the replies queries
     * (inactive/disabled queries are the replies to reply ones so we also update them to show the feedback)
     * */
    const repliesKey = {
        queryKey: (0, keys_1.getPostsKey)(),
        predicate: query => {
            var _a, _b, _c;
            const args = (_a = query === null || query === void 0 ? void 0 : query.queryKey) === null || _a === void 0 ? void 0 : _a[1];
            return ((_c = (_b = args) === null || _b === void 0 ? void 0 : _b.variables) === null || _c === void 0 ? void 0 : _c.postId) === postId;
        },
    };
    const repliesSnapshot = queryClient.getQueriesData(repliesKey);
    if (repliesSnapshot) {
        queryClient.setQueriesData(repliesKey, (0, useCachedPost_1.addPostToPaginatedPost)(newPost));
    }
    /** Add reply to the pinned posts */
    const pinnedPostsSnapshot = queryClient.getQueriesData(filters_1.pinnedPostsFilter);
    if (pinnedPostsSnapshot) {
        queryClient.setQueriesData(filters_1.pinnedPostsFilter, oldPosts => oldPosts.map((0, useCachedPost_1.infinitePostArrayUpdater)(postId, (0, useCachedPost_1.postRepliesUpdater)(newPost), false)));
    }
    /**  Add the reply to Post.replies in any posts/feed queries which the parent post exists */
    // get all active posts query
    const postsQueryFilter = {
        active: true,
        predicate: query => {
            var _a;
            const [main, args] = (query === null || query === void 0 ? void 0 : query.queryKey) || [];
            if (((_a = args) === null || _a === void 0 ? void 0 : _a.postId) !== postId &&
                (main === (0, keys_1.getFeedKey)()[0] || main === (0, keys_1.getPostsKey)()[0])) {
                return true;
            }
            return false;
        },
    };
    // take a snapshot from all matched posts queries
    const postsSnapshots = queryClient.getQueriesData(postsQueryFilter);
    // update replies within the found post everywhere (posts and the feed queries)
    queryClient.setQueriesData(postsQueryFilter, (0, useCachedPost_1.infinitePostUpdater)(postId, (0, useCachedPost_1.postRepliesUpdater)(newPost), false));
    return {
        postsSnapshots,
        rootPostSnapshot,
        repliesSnapshot,
        pinnedPostsSnapshot,
    };
};
const useAddReply = (options) => {
    const { useMutationOptions, fields = 'default' } = options || {};
    const { client } = (0, useTribeClient_1.useTribeClient)();
    const queryClient = (0, lib_1.useQueryClient)();
    return (0, lib_1.useMutation)((input) => client.posts.reply(input.postId, input, fields), {
        onSuccess: (data, variables) => {
            onAddReply(variables, data, queryClient);
        },
        ...useMutationOptions,
    });
};
exports.useAddReply = useAddReply;
//# sourceMappingURL=useAddReply.js.map