"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useDeletePost = void 0;
const lib_1 = require("../../lib");
const useTribeClient_1 = require("../../useTribeClient");
const keys_1 = require("../../utils/keys");
const useCachedPost_1 = require("../cache/useCachedPost");
const filters_1 = require("./filters");
const useDeletePost = (options) => {
    const { useMutationOptions, fields = 'basic' } = options || {};
    const { client } = (0, useTribeClient_1.useTribeClient)();
    const queryClient = (0, lib_1.useQueryClient)();
    return (0, lib_1.useMutation)((input) => client.posts.delete(input, fields), {
        onSettled: (data, error, input) => {
            const postKey = (0, keys_1.getPostKey)({ variables: { id: input === null || input === void 0 ? void 0 : input.id } });
            queryClient.removeQueries(postKey);
            const postsKey = (0, keys_1.getPostsKey)();
            queryClient.invalidateQueries(postsKey);
            const feedKey = (0, keys_1.getFeedKey)();
            queryClient.invalidateQueries(feedKey);
            const cachedPost = (0, useCachedPost_1.getCachedPost)(input.id, queryClient);
            // we want to "refetch" only replies query if any
            // (invalidate does not work for disabled queries)
            // (replies withing a reply is a disabled query)
            const parentPostId = cachedPost.repliedToId;
            if (parentPostId) {
                queryClient.refetchQueries((0, filters_1.getPostsQueryById)(parentPostId));
            }
        },
        ...useMutationOptions,
    });
};
exports.useDeletePost = useDeletePost;
//# sourceMappingURL=useDeletePost.js.map