"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useRemoveReaction = void 0;
const lib_1 = require("../../lib");
const useTribeClient_1 = require("../../useTribeClient");
const keys_1 = require("../../utils/keys");
const auth_1 = require("../auth");
const useCachedPost_1 = require("../cache/useCachedPost");
const filters_1 = require("./filters");
const useRemoveReaction = (options) => {
    const queryClient = (0, lib_1.useQueryClient)();
    const { useMutationOptions } = options || {};
    const { client } = (0, useTribeClient_1.useTribeClient)();
    const { data: authMember } = (0, auth_1.useAuthMember)();
    return (0, lib_1.useMutation)((input) => client.posts.removeReaction(input), {
        onMutate: async (variables) => {
            const { reaction, postId } = variables;
            // updating the post itself
            const postKey = (0, keys_1.getPostKey)({ variables: { id: postId } });
            await queryClient.cancelQueries(postKey);
            const postSnapshot = (0, useCachedPost_1.getCachedPost)(postId, queryClient);
            if (postSnapshot) {
                queryClient.setQueriesData(postKey, (0, useCachedPost_1.removeReactionFromPost)(reaction, authMember.id));
            }
            // updating pinned posts within the space
            const pinnedPostsSnapshot = queryClient.getQueriesData(filters_1.pinnedPostsFilter);
            if (pinnedPostsSnapshot) {
                queryClient.setQueriesData(filters_1.pinnedPostsFilter, oldPosts => oldPosts.map((0, useCachedPost_1.infinitePostArrayUpdater)(postId, (0, useCachedPost_1.removeReactionFromPost)(reaction, authMember.id), true)));
            }
            // take a snapshot from all matched posts queries
            const postsSnapshots = queryClient.getQueriesData(filters_1.postsQueryFilter);
            // update posts and replies within the found post everywhere (posts and the feed queries)
            queryClient.setQueriesData(filters_1.postsQueryFilter, (0, useCachedPost_1.infinitePostUpdater)(postId, (0, useCachedPost_1.removeReactionFromPost)(reaction, authMember.id), true));
            // updating root post if adding the reaction on a reply if no feed/posts have found
            let rootPostSnapshot;
            let rootPostKey;
            if (!(pinnedPostsSnapshot === null || pinnedPostsSnapshot === void 0 ? void 0 : pinnedPostsSnapshot.length) && !(postsSnapshots === null || postsSnapshots === void 0 ? void 0 : postsSnapshots.length)) {
                const rootPost = (0, useCachedPost_1.getCachedRootPostByReplies)(postId, queryClient);
                if (rootPost && rootPost.replies && rootPost.id !== postId) {
                    rootPostKey = (0, keys_1.getPostKey)({ variables: { id: rootPost === null || rootPost === void 0 ? void 0 : rootPost.id } });
                    rootPostSnapshot = (0, useCachedPost_1.getCachedPost)(rootPost === null || rootPost === void 0 ? void 0 : rootPost.id, queryClient);
                    if (rootPostSnapshot) {
                        queryClient.setQueriesData(rootPostKey, (0, useCachedPost_1.infinitePostArrayUpdater)(postId, (0, useCachedPost_1.removeReactionFromPost)(reaction, authMember.id), true));
                    }
                }
            }
            return [
                [postKey, postSnapshot],
                [rootPostKey, rootPostSnapshot],
                ...pinnedPostsSnapshot,
                ...postsSnapshots,
            ];
        },
        onError: (error, variables, context) => {
            context.forEach(([queryKey, snapshot]) => {
                if (queryKey) {
                    queryClient.setQueriesData(queryKey, snapshot);
                }
            });
        },
        ...useMutationOptions,
    });
};
exports.useRemoveReaction = useRemoveReaction;
//# sourceMappingURL=useRemoveReaction.js.map