"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useUpdatePost = void 0;
const lib_1 = require("../../lib");
const useTribeClient_1 = require("../../useTribeClient");
const keys_1 = require("../../utils/keys");
const filters_1 = require("./filters");
const useUpdatePost = (options) => {
    const { useMutationOptions, fields = 'withReply' } = options || {};
    const { client } = (0, useTribeClient_1.useTribeClient)();
    const queryClient = (0, lib_1.useQueryClient)();
    return (0, lib_1.useMutation)((input) => client.posts.update(input, fields), {
        onMutate: async (newPost) => {
            const postKey = (0, keys_1.getPostKey)({ variables: { id: newPost === null || newPost === void 0 ? void 0 : newPost.id } });
            await queryClient.cancelQueries(postKey);
            const snapshot = queryClient.getQueryData(postKey);
            queryClient.setQueriesData(postKey, old => ({
                ...old,
                ...newPost,
            }));
            return { snapshot };
        },
        onSuccess: updatedPost => {
            const postKey = (0, keys_1.getPostKey)({ variables: { id: updatedPost === null || updatedPost === void 0 ? void 0 : updatedPost.id } });
            queryClient.setQueriesData(postKey, oldPost => ({
                ...oldPost,
                ...updatedPost,
            }));
        },
        onError: (err, newPost, context) => {
            const postKey = (0, keys_1.getPostKey)({ variables: { id: newPost.id } });
            queryClient.setQueriesData(postKey, context.snapshot);
            queryClient.invalidateQueries(postKey);
        },
        onSettled: data => {
            const parentPostId = data.repliedToId;
            const postKey = (0, keys_1.getPostKey)();
            queryClient.invalidateQueries(postKey);
            const postsKey = (0, keys_1.getPostsKey)();
            queryClient.invalidateQueries(postsKey);
            const feedKey = (0, keys_1.getFeedKey)();
            queryClient.invalidateQueries(feedKey);
            // we want to "refetch" only replies query if any
            // (invalidate does not work for disabled queries)
            // (replies withing a reply is a disabled query)
            if (parentPostId) {
                queryClient.refetchQueries((0, filters_1.getPostsQueryById)(parentPostId));
            }
        },
        ...useMutationOptions,
    });
};
exports.useUpdatePost = useUpdatePost;
//# sourceMappingURL=useUpdatePost.js.map