"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useUpdateSpace = void 0;
const hooks_1 = require("@tribeplatform/react-sdk/hooks");
const lib_1 = require("../../lib");
const useTribeClient_1 = require("../../useTribeClient");
const keys_1 = require("../../utils/keys");
const useUpdateSpace = (options) => {
    const { useMutationOptions, fields = 'default' } = options || {};
    const { client } = (0, useTribeClient_1.useTribeClient)();
    const queryClient = (0, lib_1.useQueryClient)();
    const collectionsKey = (0, keys_1.getCollectionsKey)();
    return (0, lib_1.useMutation)((input) => client.spaces.update(input, fields), {
        onMutate: async (data) => {
            const spaceKey = (0, keys_1.getSpaceKey)({ variables: { id: data.id } });
            // Cancel any outgoing refetches (so they don't overwrite our optimistic update)
            await queryClient.cancelQueries(spaceKey);
            // Snapshot the previous value
            const snapshot = (0, hooks_1.getCachedSpace)({ id: data.id }, queryClient);
            // Optimistically update to the new value
            const spaceInput = data.input;
            const spaceUpdater = (old) => ({
                ...old,
                ...{
                    ...spaceInput,
                    slate: old === null || old === void 0 ? void 0 : old.slate,
                    address: { ...old === null || old === void 0 ? void 0 : old.address, ...spaceInput === null || spaceInput === void 0 ? void 0 : spaceInput.address },
                    seoDetail: { ...old === null || old === void 0 ? void 0 : old.seoDetail, ...spaceInput === null || spaceInput === void 0 ? void 0 : spaceInput.seoDetail },
                },
            });
            queryClient.setQueriesData(spaceKey, spaceUpdater);
            // Return a context object with the snapshotted value
            return { snapshot };
        },
        onSuccess: data => {
            const spaceKey = (0, keys_1.getSpaceKey)({ variables: { id: data.id } });
            queryClient.setQueriesData(spaceKey, oldData => ({
                ...oldData,
                ...data,
            }));
        },
        onError: (err, newSpace, context) => {
            const spaceKey = (0, keys_1.getSpaceKey)({ variables: { id: newSpace.id } });
            // revert back the optimistic response
            queryClient.setQueriesData(spaceKey, context.snapshot);
        },
        onSettled: (data, error, variables) => {
            const spacesKey = (0, keys_1.getSpacesKey)();
            queryClient.invalidateQueries(spacesKey);
            const spaceKey = (0, keys_1.getSpaceKey)({ variables: { id: variables === null || variables === void 0 ? void 0 : variables.id } });
            queryClient.invalidateQueries(spaceKey);
            queryClient.invalidateQueries(collectionsKey);
        },
        ...useMutationOptions,
    });
};
exports.useUpdateSpace = useUpdateSpace;
//# sourceMappingURL=useUpdateSpace.js.map