"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useUpdateSpaceNotificationSettings = void 0;
const lib_1 = require("../../lib");
const useTribeClient_1 = require("../../useTribeClient");
const keys_1 = require("../../utils/keys");
const useUpdateSpaceNotificationSettings = (options) => {
    const { useMutationOptions } = options || {};
    const { client } = (0, useTribeClient_1.useTribeClient)();
    const queryClient = (0, lib_1.useQueryClient)();
    const memberSettingsKey = (0, keys_1.getMemberNotificationSettingsKey)();
    return (0, lib_1.useMutation)((variables) => client.notifications.updateSpaceSettings(variables), {
        onMutate: async (newSpaceSettings) => {
            await queryClient.cancelQueries(memberSettingsKey);
            const snapshot = queryClient.getQueryData(memberSettingsKey);
            queryClient.setQueriesData(memberSettingsKey, old => {
                return {
                    ...old,
                    spaces: old.spaces.map(s => {
                        var _a, _b, _c, _d;
                        if (((_a = s === null || s === void 0 ? void 0 : s.space) === null || _a === void 0 ? void 0 : _a.id) === newSpaceSettings.spaceId &&
                            (s === null || s === void 0 ? void 0 : s.channel) === newSpaceSettings.channel) {
                            return {
                                ...s,
                                channel: newSpaceSettings.channel,
                                preference: (_b = newSpaceSettings.input.preference) !== null && _b !== void 0 ? _b : s.preference,
                                enabled: (_c = newSpaceSettings.input.enabled) !== null && _c !== void 0 ? _c : s.enabled,
                                sameAsDefault: (_d = newSpaceSettings.input.sameAsDefault) !== null && _d !== void 0 ? _d : s.sameAsDefault,
                            };
                        }
                        return s;
                    }),
                };
            });
            return { snapshot };
        },
        onError: (err, newSpace, context) => {
            // revert back the optimistic response
            queryClient.setQueriesData(memberSettingsKey, context.snapshot);
        },
        onSettled: () => {
            // invalidate to refetch again
            queryClient.invalidateQueries(memberSettingsKey);
        },
        ...useMutationOptions,
    });
};
exports.useUpdateSpaceNotificationSettings = useUpdateSpaceNotificationSettings;
//# sourceMappingURL=useUpdateSpaceNotificationSettings.js.map