"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useUploadFile = void 0;
const react_1 = require("react");
const useCreateImages_1 = require("../media/useCreateImages");
const useUploadFile = () => {
    const { mutateAsync: createImages } = (0, useCreateImages_1.useCreateImages)();
    const [loadingFile, setLoadingFile] = (0, react_1.useState)();
    const setLoading = (0, react_1.useCallback)((file) => {
        if (!file) {
            setLoadingFile(undefined);
            return;
        }
        const fr = new FileReader();
        fr.onload = () => {
            setLoadingFile({ url: fr.result });
        };
        fr.readAsDataURL(file);
    }, []);
    const uploadFile = (0, react_1.useCallback)(async (file, updater) => {
        setLoading(file);
        const args = [{ file }];
        try {
            const uploadedImage = await createImages(args, {
                onError: () => {
                    setLoading();
                },
            });
            if (typeof updater === 'function') {
                await updater(uploadedImage === null || uploadedImage === void 0 ? void 0 : uploadedImage[0]);
            }
        }
        catch (e) {
            console.log(e);
        }
        setLoading();
    }, [createImages, setLoading]);
    return {
        uploadFile,
        loadingFile,
        loading: !!loadingFile,
    };
};
exports.useUploadFile = useUploadFile;
//# sourceMappingURL=useUploadFile.js.map