import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useState, useEffect, useRef } from 'react';
import clsx from 'clsx';
import fileSize from 'filesize';
import { Carousel } from 'react-responsive-carousel';
import ArrowLeftLineIcon from 'remixicon-react/ArrowLeftLineIcon.js';
import ArrowRightLineIcon from 'remixicon-react/ArrowRightLineIcon.js';
import CloseLineIcon from 'remixicon-react/CloseLineIcon.js';
import DownloadCloud2LineIcon from 'remixicon-react/DownloadCloud2LineIcon.js';
import { Button } from '@tribeplatform/react-ui-kit/Button';
import { Modal } from '@tribeplatform/react-ui-kit/Modal';
import { MediaPreview } from './MediaPreview.js';
import { downloadFile } from './utils.js';
export const MediaModal = ({ slides, isVisible = false, onClose, activeMediaIndex = 0, }) => {
    const cache = useRef({});
    const [downloading, setDownloading] = useState(false);
    const [currentIndex, setCurrentIndex] = useState(activeMediaIndex);
    const slide = slides[currentIndex];
    const length = slides === null || slides === void 0 ? void 0 : slides.length;
    const isPreviousButtonEnabled = currentIndex > 0;
    const isNextButtonEnabled = currentIndex < length - 1;
    const handleDownload = async () => {
        const slide = slides[currentIndex];
        if (!(slide === null || slide === void 0 ? void 0 : slide.url) && !(slide === null || slide === void 0 ? void 0 : slide.downloadUrl))
            return;
        setDownloading(true);
        if (slide.downloadUrl) {
            await downloadFile(slide.downloadUrl, slide.name);
        }
        else {
            await downloadFile(slide.url);
        }
        setDownloading(false);
    };
    useEffect(() => {
        return () => {
            // clear the cache on unmount
            cache.current = {};
        };
    }, []);
    useEffect(() => {
        setCurrentIndex(activeMediaIndex);
    }, [activeMediaIndex]);
    return (_jsxs(Modal, { size: "full", open: isVisible, onClose: onClose, className: "flex-col flex", children: [_jsxs("div", { className: "px-4 py-5 sm:px-6 flex items-center justify-end border-b border-surface-200/50 space-x-1", children: [_jsxs("div", { className: "overflow-hidden flex-grow", children: [slide.name && _jsx("p", { className: "truncate", children: slide.name }, void 0), slide.size && (_jsx("p", { className: "text-basicSurface-500", children: fileSize(slide.size) }, void 0))] }, void 0), _jsxs("div", { className: "flex", children: [_jsx(Button, { size: "md", className: "hover:bg-transparent", variant: "basic", disabled: downloading, loading: downloading, leadingIcon: _jsx(DownloadCloud2LineIcon, {}, void 0), onClick: handleDownload }, void 0), _jsx(Button, { size: "md", className: "hover:bg-transparent", variant: "basic", onClick: onClose, leadingIcon: _jsx(CloseLineIcon, {}, void 0) }, void 0)] }, void 0)] }, void 0), _jsxs(Modal.Content, { className: clsx('flex items-center justify-center space-x-3 py-0', length > 1 ? 'px-3' : 'px-0 sm:p-0'), children: [length > 1 && (_jsx(Button, { variant: "outline", rounded: true, onClick: () => isPreviousButtonEnabled && setCurrentIndex(currentIndex - 1), disabled: !isPreviousButtonEnabled, leadingIcon: _jsx(ArrowLeftLineIcon, {}, void 0) }, void 0)), _jsx("div", { className: "max-h-screen flex-1", children: _jsx(Carousel, { selectedItem: currentIndex, dynamicHeight: false, showStatus: false, infiniteLoop: false, showThumbs: false, showIndicators: false, showArrows: false, transitionTime: 200, useKeyboardArrows: true, children: slides.map((slide, index) => {
                                if (cache.current[index] || index === currentIndex) {
                                    cache.current[currentIndex] = true;
                                    // Other types like video will be added later.
                                    return (_jsx(MediaPreview, { media: slide, isActive: currentIndex === index }, slide.id || slide.name));
                                }
                                return (_jsx("div", { className: "flex items-center justify-center" }, slide.id || slide.name));
                            }) }, void 0) }, void 0), length > 1 && (_jsx(Button, { variant: "outline", rounded: true, onClick: () => isNextButtonEnabled && setCurrentIndex(currentIndex + 1), disabled: !isNextButtonEnabled, leadingIcon: _jsx(ArrowRightLineIcon, {}, void 0) }, void 0))] }, void 0)] }, void 0));
};
//# sourceMappingURL=MediaModal.js.map