import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useMemo, useState } from 'react';
import { Avatar } from '@tribeplatform/react-ui-kit/Avatar';
import { Multiselect } from '@tribeplatform/react-ui-kit/Multiselect';
import { SearchableSelect } from '@tribeplatform/react-ui-kit/SearchableSelect';
import { useMembers } from '../../hooks';
import { simplifyPaginatedResult } from '../../utils';
import { pickIfExists } from './arrays.utils';
import { useDebounce } from './useDebounce';
const isMultiple = (props) => props.multiple === true;
export const MemberPicker = props => {
    var _a, _b;
    const { placeholder, variables } = props;
    const [search, setSearch] = useState('');
    const debouncedQuery = useDebounce(search, 300);
    const { data, isLoading } = useMembers({
        fields: { profilePicture: 'basic' },
        variables: {
            query: debouncedQuery,
            limit: 20,
            ...variables,
        },
    });
    const members = useMemo(() => { var _a; return ((_a = simplifyPaginatedResult(data)) === null || _a === void 0 ? void 0 : _a.nodes) || []; }, [data]);
    if (isMultiple(props)) {
        const { value, onChange } = props;
        const suggestedMembers = pickIfExists(members, value, 'id');
        return (_jsxs(Multiselect, { value: value, options: suggestedMembers, onChange: onChange, searchable: true, onInputChange: setSearch, children: [_jsx(Multiselect.Button, { placeholder: placeholder, children: value.map((member, index) => {
                        var _a, _b;
                        return (_jsx(Multiselect.SelectedItem, { value: member, index: index, children: _jsxs("div", { className: "flex items-center space-x-2", children: [_jsx(Avatar, { size: "xs", src: (_b = (_a = member === null || member === void 0 ? void 0 : member.profilePicture) === null || _a === void 0 ? void 0 : _a.urls) === null || _b === void 0 ? void 0 : _b.thumb, name: member === null || member === void 0 ? void 0 : member.name }, void 0), _jsx("span", { children: member === null || member === void 0 ? void 0 : member.name }, void 0)] }, void 0) }, member.id));
                    }) }, void 0), _jsxs(Multiselect.Items, { children: [suggestedMembers.map((member, index) => {
                            var _a, _b;
                            return (_jsx(Multiselect.Item, { value: member, index: index, children: _jsxs("div", { className: "flex items-center space-x-2", children: [_jsx(Avatar, { size: "xs", src: (_b = (_a = member === null || member === void 0 ? void 0 : member.profilePicture) === null || _a === void 0 ? void 0 : _a.urls) === null || _b === void 0 ? void 0 : _b.thumb, name: member === null || member === void 0 ? void 0 : member.name }, void 0), _jsx("span", { children: member === null || member === void 0 ? void 0 : member.name }, void 0)] }, void 0) }, member.id));
                        }), isLoading && (_jsx(Multiselect.ItemsEmpty, { children: "Loading..." }, void 0)), !isLoading && search && suggestedMembers.length === 0 && (_jsx(Multiselect.ItemsEmpty, { children: "No results" }, void 0))] }, void 0)] }, void 0));
    }
    const { value, onChange } = props;
    const suggestedMembers = value
        ? pickIfExists(members, [value], 'id')
        : members;
    return (_jsxs(SearchableSelect, { value: value, options: suggestedMembers, onChange: onChange, onInputChange: setSearch, children: [_jsx(SearchableSelect.Button, { placeholder: placeholder, children: value && (_jsxs("div", { className: "flex items-center space-x-2", children: [_jsx(Avatar, { size: "xs", src: (_b = (_a = value === null || value === void 0 ? void 0 : value.profilePicture) === null || _a === void 0 ? void 0 : _a.urls) === null || _b === void 0 ? void 0 : _b.thumb, name: value === null || value === void 0 ? void 0 : value.name }, void 0), _jsx("span", { children: value.name }, void 0)] }, void 0)) }, void 0), _jsxs(SearchableSelect.Items, { children: [suggestedMembers.map(member => {
                        var _a, _b;
                        return (_jsx(SearchableSelect.Item, { value: member.id, children: _jsxs("div", { className: "flex items-center space-x-2", children: [_jsx(Avatar, { size: "xs", src: (_b = (_a = member === null || member === void 0 ? void 0 : member.profilePicture) === null || _a === void 0 ? void 0 : _a.urls) === null || _b === void 0 ? void 0 : _b.thumb, name: member === null || member === void 0 ? void 0 : member.name }, void 0), _jsx("span", { children: member === null || member === void 0 ? void 0 : member.name }, void 0)] }, void 0) }, member.id));
                    }), isLoading && (_jsx(SearchableSelect.ItemsEmpty, { children: "Loading..." }, void 0)), !isLoading && search && suggestedMembers.length === 0 && (_jsx(SearchableSelect.ItemsEmpty, { children: "No results" }, void 0))] }, void 0)] }, void 0));
};
//# sourceMappingURL=MemberPicker.js.map