import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useMemo, useState } from 'react';
import { SpaceType, } from '@tribeplatform/gql-client/types';
import { Multiselect } from '@tribeplatform/react-ui-kit/Multiselect';
import { SearchableSelect } from '@tribeplatform/react-ui-kit/SearchableSelect';
import { useSpaces } from '../../hooks';
import { simplifyPaginatedResult } from '../../utils';
import { pickIfExists } from './arrays.utils';
import { SpaceImage } from './SpaceImage';
import { useDebounce } from './useDebounce';
const isMultiple = (props) => props.multiple === true;
export const SpacePicker = props => {
    const { placeholder, variables } = props;
    const [search, setSearch] = useState('');
    const debouncedQuery = useDebounce(search, 300);
    const { data, isLoading } = useSpaces({
        fields: { image: 'basic' },
        variables: {
            query: debouncedQuery,
            limit: 20,
            type: [SpaceType.Group],
            ...variables,
        },
    });
    const spaces = useMemo(() => { var _a; return ((_a = simplifyPaginatedResult(data)) === null || _a === void 0 ? void 0 : _a.nodes) || []; }, [data]);
    if (isMultiple(props)) {
        const { value, onChange } = props;
        const suggestedSpaces = pickIfExists(spaces, value, 'id');
        return (_jsxs(Multiselect, { value: value || [], options: suggestedSpaces, onChange: onChange, searchable: true, onInputChange: setSearch, children: [_jsx(Multiselect.Button, { placeholder: placeholder, children: value === null || value === void 0 ? void 0 : value.map((space, index) => (_jsx(Multiselect.SelectedItem, { value: space, index: index, children: _jsxs("div", { className: "flex items-center space-x-2", children: [_jsx(SpaceImage, { size: "xs", space: space }, void 0), _jsx("span", { children: space === null || space === void 0 ? void 0 : space.name }, void 0)] }, void 0) }, space.id))) }, void 0), _jsxs(Multiselect.Items, { children: [suggestedSpaces.map((space, index) => (_jsx(Multiselect.Item, { value: space, index: index, children: _jsxs("div", { className: "flex items-center space-x-2", children: [_jsx(SpaceImage, { size: "xs", space: space }, void 0), _jsx("span", { children: space === null || space === void 0 ? void 0 : space.name }, void 0)] }, void 0) }, space.id))), isLoading && (_jsx(Multiselect.ItemsEmpty, { children: "Loading..." }, void 0)), !isLoading && search && suggestedSpaces.length === 0 && (_jsx(Multiselect.ItemsEmpty, { children: "No results" }, void 0))] }, void 0)] }, void 0));
    }
    const { value, onChange } = props;
    const suggestedSpaces = value
        ? pickIfExists(spaces, [value], 'id')
        : spaces;
    return (_jsxs(SearchableSelect, { value: value, options: suggestedSpaces, onChange: onChange, onInputChange: setSearch, children: [_jsx(SearchableSelect.Button, { placeholder: placeholder, children: value && (_jsxs("div", { className: "flex items-center space-x-2", children: [_jsx(SpaceImage, { size: "xs", space: value }, void 0), _jsx("span", { children: value === null || value === void 0 ? void 0 : value.name }, void 0)] }, void 0)) }, void 0), _jsxs(SearchableSelect.Items, { children: [suggestedSpaces.map(space => (_jsx(SearchableSelect.Item, { value: space.id, children: _jsxs("div", { className: "flex items-center space-x-2", children: [_jsx(SpaceImage, { size: "xs", space: space }, void 0), _jsx("span", { children: space === null || space === void 0 ? void 0 : space.name }, void 0)] }, void 0) }, space.id))), isLoading && (_jsx(SearchableSelect.ItemsEmpty, { children: "Loading..." }, void 0)), !isLoading && search && suggestedSpaces.length === 0 && (_jsx(SearchableSelect.ItemsEmpty, { children: "No results" }, void 0))] }, void 0)] }, void 0));
};
//# sourceMappingURL=SpacePicker.js.map