import { SsoType, } from '@tribeplatform/gql-client/types';
import { useMutation, useQueryClient } from '../../lib';
import { useTribeClient } from '../../useTribeClient';
import { getSsosKey } from '../../utils/keys';
export const useUpdateJwtSso = (options) => {
    const { useMutationOptions } = options || {};
    const { client } = useTribeClient();
    const queryClient = useQueryClient();
    const ssosKey = getSsosKey();
    return useMutation((input) => client.auth.updateJwtSso(input), {
        onMutate: async (updatedJwtSso) => {
            await queryClient.cancelQueries(ssosKey);
            const snapshot = queryClient.getQueryData(ssosKey);
            queryClient.setQueriesData(ssosKey, old => [
                ...old === null || old === void 0 ? void 0 : old.filter(sso => sso.type !== SsoType.jwt),
                { ...old === null || old === void 0 ? void 0 : old.find(sso => sso.type === SsoType.jwt), ...updatedJwtSso },
            ]);
            return { snapshot };
        },
        onSuccess: updatedJwtSso => {
            queryClient.setQueriesData(ssosKey, old => [
                ...old === null || old === void 0 ? void 0 : old.filter(sso => sso.type !== SsoType.jwt),
                { ...old === null || old === void 0 ? void 0 : old.find(sso => sso.type === SsoType.jwt), ...updatedJwtSso },
            ]);
        },
        onError: (_, __, context) => {
            queryClient.setQueriesData(ssosKey, context.snapshot);
        },
        onSettled: () => {
            queryClient.invalidateQueries(ssosKey);
        },
        ...useMutationOptions,
    });
};
//# sourceMappingURL=useUpdateJwtSso.js.map