import { useCachedNetwork } from '@tribeplatform/react-sdk/hooks';
import { useMutation, useQueryClient } from '../../lib';
import { useTribeClient } from '../../useTribeClient';
import { getAuthTokenKey, getNetworkKey } from '../../utils/keys';
export const useUpdateNetwork = (options) => {
    const { useMutationOptions, fields } = options || {};
    const { client } = useTribeClient();
    const queryClient = useQueryClient();
    const networkKey = getNetworkKey();
    const authTokenKey = getAuthTokenKey();
    const networkSnapshot = useCachedNetwork();
    return useMutation((input) => client.network.update(input, fields), {
        onMutate: async (variables) => {
            // Cancel any outgoing refetches (so they don't overwrite our optimistic update)
            await queryClient.cancelQueries(networkKey);
            // Snapshot the previous value
            const snapshot = networkSnapshot;
            // Optimistically update to the new value
            // We are removing navigationSlates here because of type conflict
            const networkInput = variables.input;
            const networkUpdater = (old) => ({
                ...old,
                ...networkInput,
                navigationSlates: old === null || old === void 0 ? void 0 : old.navigationSlates,
                landingPages: null,
            });
            queryClient.setQueriesData(networkKey, networkUpdater);
            // TODO: find a way to automatically update the network
            queryClient.setQueriesData(authTokenKey, old => ({
                ...old,
                network: networkUpdater(old.network),
            }));
            // Return a context object with the snapshotted value
            return { snapshot };
        },
        onSuccess: data => {
            queryClient.setQueriesData(networkKey, oldData => ({
                ...oldData,
                ...data,
            }));
        },
        onError: (err, newNetwork, context) => {
            // revert back the optimistic response
            queryClient.setQueriesData(networkKey, context.snapshot);
        },
        onSettled: () => {
            // Re-fetch the network
            queryClient.invalidateQueries(networkKey);
            // Re-fetch the auth tokens
            queryClient.invalidateQueries(authTokenKey);
        },
        ...useMutationOptions,
    });
};
//# sourceMappingURL=useUpdateNetwork.js.map