import { useMutation, useQueryClient } from '../../lib';
import { useTribeClient } from '../../useTribeClient';
import { getAuthTokenKey, getNetworkKey } from '../../utils/keys';
import { authTokenUpdater, networkUpdater, useCachedNetwork } from '../cache';
export const useUpsertTheme = (options) => {
    const { useMutationOptions, fields } = options || {};
    const { client } = useTribeClient();
    const queryClient = useQueryClient();
    const networkKey = getNetworkKey();
    const authTokenKey = getAuthTokenKey();
    const networkSnapshot = useCachedNetwork();
    return useMutation((input) => client.theme.upsert(input, fields), {
        onMutate: async (newTheme) => {
            var _a;
            const snapshot = networkSnapshot;
            if ((_a = newTheme.input) === null || _a === void 0 ? void 0 : _a.active) {
                await queryClient.cancelQueries(networkKey);
                queryClient.setQueriesData(networkKey, networkUpdater({ activeTheme: newTheme.input }));
                queryClient.setQueriesData(authTokenKey, authTokenUpdater({
                    network: { activeTheme: newTheme.input },
                }));
            }
            return { snapshot };
        },
        onSuccess: newTheme => {
            queryClient.setQueriesData(authTokenKey, authTokenUpdater({
                network: { activeTheme: newTheme },
            }));
        },
        onError: (err, newTheme, context) => {
            queryClient.setQueriesData(networkKey, context.snapshot);
            queryClient.setQueriesData(authTokenKey, authTokenUpdater({ network: context.snapshot }));
        },
        onSettled: () => {
            queryClient.invalidateQueries(networkKey);
            queryClient.invalidateQueries(authTokenKey);
        },
        ...useMutationOptions,
    });
};
//# sourceMappingURL=useUpsertTheme.js.map