import { FC, useState } from 'react'

import Link from '@tiptap/extension-link'
import Placeholder from '@tiptap/extension-placeholder'
import Underline from '@tiptap/extension-underline'
import { EditorContent, useEditor } from '@tiptap/react'
import StarterKit from '@tiptap/starter-kit'
import clsx from 'clsx'

import {
  FormControl,
  FormControlProps,
} from '@tribeplatform/react-ui-kit/FormControl'

import { TextFormattingMenu } from './TextBubbleMenu'

export type FormControlHtmlEditorProps = FormControlProps & {
  value?: string
  onChange?: (value: string) => void
}

export const FormControlHtmlEditor: FC<FormControlHtmlEditorProps> = ({
  placeholder,
  name,
  value,
  error,
  invalid,
  label,
  helperText,
  onChange,
}) => {
  const [focused, setFocused] = useState(false)

  const editor = useEditor({
    onUpdate: ({ editor }) => {
      onChange(editor.isEmpty ? '' : editor.getHTML())
    },
    onFocus: () => {
      setFocused(true)
    },
    onBlur: () => {
      setFocused(false)
    },
    extensions: [
      StarterKit,
      Underline,
      Link,
      Placeholder.configure({
        placeholder,
      }),
    ],
    editorProps: {
      attributes: {
        class: 'flex-1',
      },
    },
    content: value,
  })

  if (!editor) return null

  return (
    <div>
      {label ? (
        <FormControl.Label htmlFor={name}>{label}</FormControl.Label>
      ) : null}
      <div className={clsx(!!label && 'mt-1')}>
        <div
          // h-28 is not working !?
          style={{ minHeight: '114px' }}
          className={clsx(
            'flex flex-col relative shadow-sm min-h-28 px-3 py-2 border w-full rounded-md text-basicSurface-500 bg-surface-50 placeholder-basicSurface-300/75 border-basicSurface-300/25',
            focused &&
              'outline border-actionPrimary-500 ring-actionPrimary-500',
            invalid && 'pr-10 outline ring-danger-500 border-danger-500',
          )}
        >
          <div className="inline-block mb-2 overflow-auto">
            <TextFormattingMenu
              editor={editor}
              className="shadow-none border-none bg-transparent px-0"
            />
          </div>
          <EditorContent editor={editor} className="flex flex-col flex-1" />
        </div>
        <FormControl.Meta
          invalid={invalid}
          error={error}
          helperText={helperText}
        />
      </div>
    </div>
  )
}
