import { Controller, useFormContext } from 'react-hook-form'

import { FormControlProps } from '@tribeplatform/react-ui-kit/FormControl'

import { FormValidationProps } from '../typings'
import {
  FormControlHtmlEditor,
  FormControlHtmlEditorProps,
} from './FormControlHtmlEditor'

export type SimpleHtmlEditorProps = FormControlProps &
  FormValidationProps &
  FormControlHtmlEditorProps

export function SimpleHtmlEditor({
  name,
  validation,
  error: ___,
  onChange: selectOnChange,
  ...rest
}: SimpleHtmlEditorProps) {
  const { control } = useFormContext()

  return (
    <Controller
      control={control}
      name={name}
      rules={validation}
      render={({ field: { onChange, value }, fieldState: { error } }) => (
        <FormControlHtmlEditor
          name={name}
          invalid={!!error?.message}
          error={error?.message}
          onChange={value => {
            onChange(value)
            if (typeof selectOnChange === 'function') selectOnChange(value)
          }}
          value={value}
          {...rest}
        />
      )}
    />
  )
}
