import { Editor } from '@tiptap/react'
import BoldIcon from 'remixicon-react/BoldIcon'
import CodeBoxLineIcon from 'remixicon-react/CodeBoxLineIcon'
import CodeLinkIcon from 'remixicon-react/CodeLineIcon'
import DoubleQuotesLIcon from 'remixicon-react/DoubleQuotesLIcon'
import H1Icon from 'remixicon-react/H1Icon'
import H2Icon from 'remixicon-react/H2Icon'
import ItalicIcon from 'remixicon-react/ItalicIcon'
import StrikethroughIcon from 'remixicon-react/StrikethroughIcon'
import UnderlineIcon from 'remixicon-react/UnderlineIcon'
import { twMerge } from 'tailwind-merge'

import { MenuItem } from './BubbleMenuItem'

export const TextFormattingMenu = ({
  editor,
  className,
}: {
  editor: Editor
  className?: string
}) => (
  <>
    <div
      className={twMerge(
        'flex items-center rounded-sm space-x-2 divide-x divide-surface-200 py-1 px-2 text-basicSurface-500 bg-surface-50 shadow-lg border border-surface-200/50',
        className,
      )}
    >
      <div className="flex space-x-2">
        <MenuItem
          title="Bold"
          onClick={() => editor.chain().focus().toggleBold().run()}
          isActive={editor.isActive('bold')}
          icon={<BoldIcon />}
        />
        <MenuItem
          title="Italic"
          onClick={() => editor.chain().focus().toggleItalic().run()}
          isActive={editor.isActive('italic')}
          icon={<ItalicIcon />}
        />
        <MenuItem
          title="Underline"
          onClick={() => editor.chain().focus().toggleUnderline().run()}
          isActive={editor.isActive('underline')}
          icon={<UnderlineIcon />}
        />
        <MenuItem
          title="Strike Through"
          onClick={() => editor.chain().focus().toggleStrike().run()}
          isActive={editor.isActive('strike')}
          icon={<StrikethroughIcon />}
        />
      </div>
      <div className="flex space-x-2 pl-2">
        <MenuItem
          title="Large Header"
          onClick={() =>
            editor.chain().focus().toggleHeading({ level: 2 }).run()
          }
          isActive={editor.isActive('heading', { level: 2 })}
          icon={<H1Icon />}
        />
        <MenuItem
          title="Medium Header"
          onClick={() =>
            editor.chain().focus().toggleHeading({ level: 3 }).run()
          }
          isActive={editor.isActive('heading', { level: 3 })}
          icon={<H2Icon />}
        />
      </div>
      <div className="flex pl-2">
        <MenuItem
          title="Blockquote"
          onClick={() => editor.chain().focus().toggleBlockquote().run()}
          isActive={editor.isActive('blockquote')}
          icon={<DoubleQuotesLIcon />}
        />
      </div>
      <div className="flex space-x-2 pl-2">
        <MenuItem
          title="Inline Code"
          onClick={() => editor.chain().focus().toggleCode().run()}
          isActive={editor.isActive('code')}
          icon={<CodeLinkIcon />}
        />
        <MenuItem
          title="Code Block"
          onClick={() => editor.chain().focus().toggleCodeBlock().run()}
          isActive={editor.isActive('codeBlock')}
          icon={<CodeBoxLineIcon />}
        />
      </div>
    </div>
  </>
)
