import { ReactNode } from 'react'

import { Controller, useFormContext } from 'react-hook-form'

import {
  FormControl,
  FormControlMultiselectProps,
} from '@tribeplatform/react-ui-kit/FormControl'

import { FormValidationProps } from './typings'

export type MultiselectProps = Omit<
  FormControlMultiselectProps,
  'value' | 'onChange' | 'children'
> &
  FormValidationProps & {
    value?: string[]
    onChange?: (newValue: string[]) => void
    children?: ReactNode
  }

export function Multiselect({
  name,
  validation,
  error: ___,
  onChange: multiselectOnChange,
  value: __,
  ...rest
}: MultiselectProps) {
  const { control } = useFormContext()

  return (
    <Controller
      control={control}
      name={name}
      rules={validation}
      render={({ field: { onChange, value }, fieldState: { error } }) => (
        <FormControl.Multiselect
          name={name}
          invalid={!!error?.message}
          error={error?.message}
          value={value}
          onChange={value => {
            onChange(value)
            if (typeof multiselectOnChange === 'function')
              multiselectOnChange(value)
          }}
          {...rest}
        />
      )}
    />
  )
}
