import { Controller, useFormContext } from 'react-hook-form'

import {
  FormControl,
  FormControlRadioGroupProps,
} from '@tribeplatform/react-ui-kit/FormControl'

import { FormValidationProps } from './typings'

export type RadioGroupProps = Omit<
  FormControlRadioGroupProps,
  'value' | 'onChange'
> &
  FormValidationProps & {
    value?: any
    onChange?: (newValue: any) => void
  }

export function RadioGroup({
  children,
  name,
  validation,
  ...rest
}: RadioGroupProps) {
  const { control } = useFormContext()

  return (
    <Controller
      control={control}
      name={name}
      rules={validation}
      defaultValue=""
      render={({ field: { onChange, value }, fieldState: { error } }) => (
        <FormControl.RadioGroup
          name={name}
          invalid={!!error?.message}
          error={error?.message}
          value={value}
          onChange={value => {
            onChange(value)
          }}
          {...rest}
        >
          {children}
        </FormControl.RadioGroup>
      )}
    />
  )
}
