import { Controller, useFormContext } from 'react-hook-form'

import {
  FormControl,
  FormControlSearchableSelectProps,
} from '@tribeplatform/react-ui-kit/FormControl'

import { FormValidationProps } from './typings'

export type SearchableSelectProps = Omit<
  FormControlSearchableSelectProps,
  'value' | 'onChange'
> &
  FormValidationProps & {
    value?: FormControlSearchableSelectProps['value']
    onChange?: FormControlSearchableSelectProps['onChange']
  }

export function SearchableSelect({
  name,
  validation,
  error: ___,
  onChange: selectOnChange,
  value: __,
  ...rest
}: SearchableSelectProps) {
  const { control } = useFormContext()

  return (
    <Controller
      control={control}
      name={name}
      rules={validation}
      render={({ field: { onChange, value }, fieldState: { error } }) => (
        <FormControl.SearchableSelect
          name={name}
          invalid={!!error?.message}
          error={error?.message}
          value={value}
          onChange={value => {
            onChange(value)
            if (typeof selectOnChange === 'function') selectOnChange(value)
          }}
          {...rest}
        />
      )}
    />
  )
}
