import clsx from 'clsx'
import { Element } from 'html-react-parser'
import ReactPlayer from 'react-player/lazy'

import { AppsEnum } from './@types'

export const renderVideo = (domNode: Element, { className }) => (
  <figure>
    <div className={clsx('aspect-video', className)}>
      <ReactPlayer
        width="100%"
        height="100%"
        controls
        url={domNode.attribs.src}
      />
    </div>
  </figure>
)

export const renderAudio = (domNode: Element) => (
  <figure>
    <div className="h-16">
      <ReactPlayer
        config={{ file: { forceAudio: true } }}
        width="100%"
        height="100%"
        controls
        url={domNode.attribs.src}
      />
    </div>
  </figure>
)

export const renderImg = (
  domNode: Element,
  { mediaIndex, className, onClick },
) => {
  const app = domNode?.attribs?.['data-app']
  const isGiphy = app === AppsEnum.Giphy
  return (
    <figure>
      <div
        className={clsx(
          'flex items-center mt-5 ignore-typography',
          !isGiphy && `justify-center bg-surface-100 ${className}`,
        )}
        data-index={mediaIndex}
        onClick={onClick}
      >
        <img
          src={domNode.attribs.src}
          className={clsx('cursor-pointer', isGiphy ? 'max-h-48' : 'max-h-120')}
          alt=""
        />
      </div>
    </figure>
  )
}
