import React from 'react'

import clsx from 'clsx'

import { File } from '@tribeplatform/gql-client/types'
import { Player } from '@tribeplatform/react-ui-kit'

import { Slide } from './@types.js'

export const PREVIEW_SUPPORTED_EXTENSION = [
  'jpg',
  'jpeg',
  'png',
  'jiff',
  'gif',
  'pdf',
  'svg',
  'mp4',
  'ogg',
  'mp3',
  'wav',
]

const containerHeight = 'calc(100vh - 170px)'

export const MediaPreview = ({
  media,
  isActive,
}: {
  isActive: boolean
  media: Slide
}) => {
  const { name, url } = media
  const extension = (media as File)?.extension?.toLowerCase()

  if (extension && !PREVIEW_SUPPORTED_EXTENSION.includes(extension))
    return (
      <div className="flex h-full w-full items-center justify-center">
        <p>Preview not supported</p>
      </div>
    )

  if (extension === 'pdf')
    return (
      <iframe
        className="rounded-b"
        title={name}
        src={url}
        style={{
          height: containerHeight,
        }}
      />
    )

  if (['mp4', 'ogg', 'mp3', 'wav'].indexOf(extension) !== -1) {
    const isAudio = extension !== 'mp4'
    return (
      <div
        className="flex items-center justify-center"
        style={{
          height: containerHeight,
        }}
      >
        <div
          className={clsx(
            'w-full max-h-full flex items-center',
            !isAudio ? 'aspect-video' : 'h-16',
          )}
        >
          <Player
            controls
            playing={isActive}
            config={{ file: { forceAudio: isAudio } }}
            muted={!isAudio}
            width="100%"
            height={isAudio ? '50px' : '100%'}
            style={{
              display: 'flex',
              width: '100%',
            }}
            url={url}
          />
        </div>
      </div>
    )
  }

  return (
    <div
      className="flex items-center justify-center"
      style={{
        height: containerHeight,
      }}
    >
      <img
        src={url}
        className="object-contain max-h-full"
        alt={name}
        loading="lazy"
      />
    </div>
  )
}
