import * as factory from '@tribeplatform/test-utils/factory'
import { mockAppInstallations } from '@tribeplatform/test-utils/handlers'

import { renderHook } from '../../../tests/render'
import { server } from '../../../tests/server'
import { simplifyPaginatedResult } from '../../utils'
import { useAppInstallations } from './useAppInstallations'

describe('useAppInstallations', () => {
  describe('happy path', () => {
    const appInstallation1 = factory.appInstallation()

    beforeEach(() => {
      server.use(mockAppInstallations([appInstallation1]))
    })

    test('returns basic fields', async () => {
      const { result, waitFor } = renderHook(() =>
        useAppInstallations({
          variables: {
            limit: 10,
          },
          fields: 'basic',
        }),
      )

      await waitFor(() => result.current.isSuccess)

      expect(simplifyPaginatedResult(result.current.data).nodes).toEqual([
        appInstallation1,
      ])
    })

    test('returns all fields', async () => {
      const { result, waitFor } = renderHook(() =>
        useAppInstallations({
          variables: {
            limit: 10,
          },
          fields: 'all',
        }),
      )

      await waitFor(() => result.current.isSuccess)

      expect(simplifyPaginatedResult(result.current.data).nodes).toEqual([
        appInstallation1,
      ])
    })
  })
})
