import * as factory from '@tribeplatform/test-utils/factory'
import { mockApps } from '@tribeplatform/test-utils/handlers'

import { renderHook } from '../../../tests/render'
import { server } from '../../../tests/server'
import { simplifyPaginatedResult } from '../../utils'
import { useApps } from './useApps'

describe('useApps', () => {
  describe('happy path', () => {
    const app = factory.app({
      name: 'App 1',
    })

    beforeEach(() => {
      server.use(mockApps([app]))
    })

    test('returns basic fields', async () => {
      const { result, waitFor } = renderHook(() =>
        useApps({
          variables: {
            limit: 10,
          },
          fields: 'basic',
        }),
      )

      await waitFor(() => result.current.isSuccess)

      expect(simplifyPaginatedResult(result.current.data).nodes).toEqual([app])
    })

    test('returns all fields', async () => {
      const { result, waitFor } = renderHook(() =>
        useApps({
          variables: {
            limit: 10,
          },
          fields: 'all',
        }),
      )

      await waitFor(() => result.current.isSuccess)

      expect(simplifyPaginatedResult(result.current.data).nodes).toEqual([app])
    })
  })
})
