import { MemberFields } from '@tribeplatform/gql-client'
import { Member, RoleType } from '@tribeplatform/gql-client/types'

import { useQuery, UseQueryOptions } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getAuthMemberKey } from '../../utils/keys'
import { useCachedAuthMember } from '../cache'

export const useAuthMember = (options?: {
  useQueryOptions?: UseQueryOptions<Member>
  fields: MemberFields
}) => {
  const { useQueryOptions, fields = 'default' } = options || {}
  const { client } = useTribeClient()
  const authMemberKey = getAuthMemberKey({ fields })

  const query = useQuery<Member>(
    authMemberKey,
    () => client.auth.authMember(fields),
    {
      placeholderData: useCachedAuthMember(),
      ...useQueryOptions,
    },
  )

  const member = query?.data
  const isAdmin = member?.role?.type === RoleType.admin
  const isModerator =
    member?.role?.type === RoleType.moderator ||
    member?.role?.type === RoleType.admin
  const isGuest =
    !member || !member?.role?.type || member?.role?.type === RoleType.guest

  return {
    isAdmin,
    isGuest,
    isModerator,
    ...query,
  }
}
