import { AuthTokenFields } from '@tribeplatform/gql-client'
import { AuthToken } from '@tribeplatform/gql-client/types'
import { useCachedAuthToken } from '@tribeplatform/react-sdk/hooks'

import { useQuery, UseQueryOptions } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getAuthTokenKey } from '../../utils/keys'

export const useAuthToken = (options?: {
  useQueryOptions?: UseQueryOptions<AuthToken>
  fields?: AuthTokenFields
}) => {
  const { useQueryOptions, fields = 'default' } = options || {}
  const { client, config, onTokenUpdate } = useTribeClient()
  const authTokenKey = getAuthTokenKey({ fields })
  const { networkDomain } = config || {}

  return useQuery<AuthToken>(
    authTokenKey,
    () => client.getTokens({ networkDomain }, fields),
    {
      placeholderData: useCachedAuthToken(),
      onSuccess: data => {
        client.setToken(data.accessToken)
        if (typeof onTokenUpdate === 'function') {
          onTokenUpdate(data)
        }
        if (typeof useQueryOptions?.onSuccess === 'function') {
          useQueryOptions.onSuccess(data)
        }
      },
      ...useQueryOptions,
    },
  )
}
