import { ClientError, MemberInvitationFields } from '@tribeplatform/gql-client'
import {
  MemberInvitation,
  MutationInviteMembersArgs,
} from '@tribeplatform/gql-client/types'

import { useMutation, UseMutationOptions, useQueryClient } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getMemberInvitationsKey } from '../../utils/keys'

export const useInviteMembers = (options?: {
  fields?: MemberInvitationFields
  useMutationOptions?: UseMutationOptions<
    Array<MemberInvitation>,
    ClientError,
    MutationInviteMembersArgs
  >
}) => {
  const { useMutationOptions, fields = 'basic' } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()

  return useMutation<
    Array<MemberInvitation>,
    ClientError,
    MutationInviteMembersArgs
  >(
    (input: MutationInviteMembersArgs) =>
      client.invitations.invite(input, fields),
    {
      onSettled: () => {
        const memberInvitationsKey = getMemberInvitationsKey()
        queryClient.invalidateQueries(memberInvitationsKey)
      },
      ...useMutationOptions,
    },
  )
}
