import { Context } from 'vm'

import { ClientError } from '@tribeplatform/gql-client/lib'
import {
  MutationUpdateJwtSsoArgs,
  Sso,
  SsoType,
} from '@tribeplatform/gql-client/types'

import { useMutation, UseMutationOptions, useQueryClient } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getSsosKey } from '../../utils/keys'

export const useUpdateJwtSso = (options?: {
  useMutationOptions?: UseMutationOptions<
    Sso,
    ClientError,
    MutationUpdateJwtSsoArgs,
    { snapshot: Sso }
  >
}) => {
  const { useMutationOptions } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()
  const ssosKey = getSsosKey()

  return useMutation<Sso, ClientError, MutationUpdateJwtSsoArgs>(
    (input: MutationUpdateJwtSsoArgs) => client.auth.updateJwtSso(input),
    {
      onMutate: async updatedJwtSso => {
        await queryClient.cancelQueries(ssosKey)
        const snapshot = queryClient.getQueryData<Sso[]>(ssosKey)

        queryClient.setQueriesData<Sso[]>(ssosKey, old => [
          ...old?.filter(sso => sso.type !== SsoType.jwt),
          { ...old?.find(sso => sso.type === SsoType.jwt), ...updatedJwtSso },
        ])

        return { snapshot }
      },
      onSuccess: updatedJwtSso => {
        queryClient.setQueriesData<Sso[]>(ssosKey, old => [
          ...old?.filter(sso => sso.type !== SsoType.jwt),
          { ...old?.find(sso => sso.type === SsoType.jwt), ...updatedJwtSso },
        ])
      },
      onError: (_, __, context: Context) => {
        queryClient.setQueriesData<Sso[]>(ssosKey, context.snapshot)
      },
      onSettled: () => {
        queryClient.invalidateQueries(ssosKey)
      },
      ...useMutationOptions,
    },
  )
}
