import { ClientError } from '@tribeplatform/gql-client'
import {
  Action,
  MutationAssignBadgeArgs,
} from '@tribeplatform/gql-client/types'

import { useMutation, UseMutationOptions, useQueryClient } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getMemberKey } from '../../utils/keys'

export const useAssignBadge = (options?: {
  useMutationOptions?: UseMutationOptions<
    Action,
    ClientError,
    MutationAssignBadgeArgs
  >
}) => {
  const { useMutationOptions } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()

  return useMutation<Action, ClientError, MutationAssignBadgeArgs>(
    input => client.badge.assign(input),
    {
      onSettled: (data, error, variables) => {
        const memberKey = getMemberKey({
          variables: { id: variables?.input?.memberId },
        })
        queryClient.invalidateQueries(memberKey)
      },
      ...useMutationOptions,
    },
  )
}
