import { ClientError } from '@tribeplatform/gql-client'
import {
  Action,
  MutationDeleteBadgeArgs,
} from '@tribeplatform/gql-client/types'

import { useMutation, UseMutationOptions, useQueryClient } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getNetworkKey, getAuthTokenKey } from '../../utils/keys'

export const useDeleteBadge = (options?: {
  useMutationOptions?: UseMutationOptions<
    Action,
    ClientError,
    MutationDeleteBadgeArgs
  >
}) => {
  const { useMutationOptions } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()
  const networkKey = getNetworkKey()
  const authTokenKey = getAuthTokenKey()

  return useMutation<Action, ClientError, MutationDeleteBadgeArgs>(
    input => client.badge.delete(input),
    {
      onMutate: () => {
        queryClient.cancelQueries(networkKey)
        queryClient.cancelQueries(authTokenKey)
      },
      onSettled: () => {
        queryClient.invalidateQueries(networkKey)
        queryClient.invalidateQueries(authTokenKey)
      },
      ...useMutationOptions,
    },
  )
}
