import { ClientError } from '@tribeplatform/gql-client'
import {
  Action,
  MutationRevokeBadgeArgs,
} from '@tribeplatform/gql-client/types'

import { useMutation, UseMutationOptions, useQueryClient } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getMemberKey } from '../../utils/keys'

export const useRevokeBadge = (options?: {
  useMutationOptions?: UseMutationOptions<
    Action,
    ClientError,
    MutationRevokeBadgeArgs
  >
}) => {
  const { useMutationOptions } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()

  return useMutation<Action, ClientError, MutationRevokeBadgeArgs>(
    input => client.badge.revoke(input),
    {
      onSettled: (data, error, variables) => {
        const memberKey = getMemberKey({
          variables: { id: variables?.input?.memberId },
        })
        queryClient.invalidateQueries(memberKey)
      },
      ...useMutationOptions,
    },
  )
}
