import { BadgeFields, ClientError } from '@tribeplatform/gql-client'
import { Badge, MutationUpdateBadgeArgs } from '@tribeplatform/gql-client/types'

import { useMutation, UseMutationOptions, useQueryClient } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getNetworkKey, getAuthTokenKey } from '../../utils/keys'

export const useUpdateBadge = (options?: {
  fields?: BadgeFields
  useMutationOptions?: UseMutationOptions<
    Badge,
    ClientError,
    MutationUpdateBadgeArgs
  >
}) => {
  const { useMutationOptions, fields = 'basic' } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()
  const networkKey = getNetworkKey()
  const authTokenKey = getAuthTokenKey()

  return useMutation<Badge, ClientError, MutationUpdateBadgeArgs>(
    input => client.badge.update(input, fields),
    {
      onMutate: () => {
        queryClient.cancelQueries(networkKey)
        queryClient.cancelQueries(authTokenKey)
      },
      onSettled: () => {
        queryClient.invalidateQueries(networkKey)
        queryClient.invalidateQueries(authTokenKey)
      },
      ...useMutationOptions,
    },
  )
}
