import { ClientError } from '@tribeplatform/gql-client'
import {
  BillingDetails,
  MutationUpdateBillingDetailsArgs,
} from '@tribeplatform/gql-client/types'

import { useMutation, UseMutationOptions, useQueryClient } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getBillingDetailsKey } from '../../utils/keys'

export const useUpdateBillingDetails = (options?: {
  useMutationOptions?: UseMutationOptions<
    BillingDetails,
    ClientError,
    MutationUpdateBillingDetailsArgs
  >
}) => {
  const { useMutationOptions } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()

  return useMutation<
    BillingDetails,
    ClientError,
    MutationUpdateBillingDetailsArgs
  >(input => client.billing.updateDetails(input), {
    onSettled: () => {
      const billingDetailsKey = getBillingDetailsKey()
      queryClient.invalidateQueries(billingDetailsKey)
    },
    ...useMutationOptions,
  })
}
