import { ClientError, CollectionFields } from '@tribeplatform/gql-client'
import {
  Collection,
  MutationCreateCollectionArgs,
} from '@tribeplatform/gql-client/types'

import { useMutation, UseMutationOptions, useQueryClient } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getCollectionsKey } from '../../utils/keys'

export const useCreateCollection = (options?: {
  fields?: CollectionFields
  useMutationOptions?: UseMutationOptions<
    Collection,
    ClientError,
    MutationCreateCollectionArgs,
    { snapshot: Collection }
  >
}) => {
  const { useMutationOptions, fields } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()

  const collectionsKey = getCollectionsKey()

  return useMutation<
    Collection,
    ClientError,
    MutationCreateCollectionArgs,
    { snapshot: Collection }
  >(
    (input: MutationCreateCollectionArgs) =>
      client.collections.create(input, fields),
    {
      onSuccess: async _ => {
        queryClient.invalidateQueries(collectionsKey)
      },
      ...useMutationOptions,
    },
  )
}
