import { ActionFields } from '@tribeplatform/gql-client/graphql'
import { ClientError } from '@tribeplatform/gql-client/lib'
import {
  Action,
  MutationDeleteCollectionArgs,
} from '@tribeplatform/gql-client/types'

import { useMutation, UseMutationOptions, useQueryClient } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getCollectionKey, getCollectionsKey } from '../../utils/keys'

export const useDeleteCollection = (options?: {
  fields?: ActionFields
  useMutationOptions?: UseMutationOptions<
    Action,
    ClientError,
    MutationDeleteCollectionArgs
  >
}) => {
  const { useMutationOptions } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()

  return useMutation<Action, ClientError, MutationDeleteCollectionArgs>(
    input => client.collections.delete(input.id),
    {
      onSettled: (data, error, input) => {
        const collectionKey = getCollectionKey({ variables: input })
        queryClient.removeQueries(collectionKey)

        const collectionsKey = getCollectionsKey()
        queryClient.invalidateQueries(collectionsKey)
      },
      ...useMutationOptions,
    },
  )
}
