import { Types } from '@tribeplatform/gql-client'

import { useMutation, UseMutationOptions, useQueryClient } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getAppKey, getAppsKey } from '../../utils/keys'

export const useGlobalDeleteApp = (options?: {
  useMutationOptions?: UseMutationOptions<
    Types.App,
    Error,
    Types.MutationGlobalDeleteAppArgs
  >
}) => {
  const { useMutationOptions } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()

  const appsKey = getAppsKey()

  return useMutation<Types.App, Error, Types.MutationGlobalDeleteAppArgs>(
    (input: Types.MutationGlobalDeleteAppArgs) => client?.dev.deleteApp(input),
    {
      onSuccess: async data => {
        const appKey = getAppKey({ variables: { slug: data.slug } })

        queryClient.removeQueries(appKey)
        queryClient.invalidateQueries(appsKey)
      },
      ...useMutationOptions,
    },
  )
}
