import { ClientError } from '@tribeplatform/gql-client'
import {
  MutationUpdateNetworkMediaSettingsArgs,
  Network,
  MediaNetworkSettings,
} from '@tribeplatform/gql-client/types'
import { useCachedNetwork } from '@tribeplatform/react-sdk/hooks'

import { useMutation, UseMutationOptions, useQueryClient } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getNetworkKey } from '../../utils/keys'

export const useUpdateNetworkMediaSettings = (options?: {
  useMutationOptions?: UseMutationOptions<
    MediaNetworkSettings,
    ClientError,
    MutationUpdateNetworkMediaSettingsArgs,
    { snapshot: Network }
  >
}) => {
  const { useMutationOptions } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()
  const networkKey = getNetworkKey()
  const networkSnapshot = useCachedNetwork()

  return useMutation<
    MediaNetworkSettings,
    ClientError,
    MutationUpdateNetworkMediaSettingsArgs,
    { snapshot: Network }
  >(variables => client.media.updateNetworkSettings(variables), {
    onMutate: async newNetworkMediaSettings => {
      await queryClient.cancelQueries(networkKey)

      const snapshot = networkSnapshot

      queryClient.setQueriesData<Network>(networkKey, old => {
        return {
          ...old,
          settings: {
            ...old?.settings,
            fileSizeLimit:
              newNetworkMediaSettings?.input?.fileSizeLimit ??
              old?.settings?.fileSizeLimit,
            imageSizeLimit:
              newNetworkMediaSettings?.input?.imageSizeLimit ??
              old?.settings?.imageSizeLimit,
          },
        }
      })

      return { snapshot }
    },
    onError: (err, newNetworkSettings, context) => {
      // revert back the optimistic response
      queryClient.setQueriesData<Network>(networkKey, context.snapshot)
    },
    onSettled: () => {
      // invalidate to refetch again
      queryClient.invalidateQueries(networkKey)
    },
    ...useMutationOptions,
  })
}
