import { createDehydratedState } from '@tribeplatform/test-utils/cache'
import * as factory from '@tribeplatform/test-utils/factory'
import { mockMember } from '@tribeplatform/test-utils/handlers'

import { renderHook } from '../../../tests/render'
import { server } from '../../../tests/server'
import { getPostKey } from '../../utils/keys'
import { useMember } from './useMember'

describe('useMember', () => {
  describe('happy path', () => {
    const member = factory.member({
      name: 'Member 1',
    })
    beforeEach(() => {
      server.use(mockMember(member))
    })

    test('returns fields', async () => {
      const { result, waitFor } = renderHook(() =>
        useMember({
          variables: {
            id: member.id,
          },
        }),
      )

      await waitFor(() => result.current.isSuccess)
      expect(result.current.isPlaceholderData).toEqual(true)
      expect(result.current.data).toEqual(null)

      await waitFor(() => !result.current.isPlaceholderData)
      expect(result.current.data).toEqual(member)
    })
  })

  describe.skip('cached data', () => {
    const member = factory.member({
      name: 'Member 1',
    })

    beforeEach(() => {
      server.use(mockMember(member))
    })

    test('returns data from post', async () => {
      const post = factory.post({
        owner: { member },
      })
      const dehydratedState = createDehydratedState([
        [getPostKey({ variables: { id: post?.id } }), post],
      ])

      const { result, waitFor } = renderHook(
        () =>
          useMember({
            variables: {
              id: member.id,
            },
          }),
        { dehydratedState },
      )

      await waitFor(() => result.current.isSuccess)
      expect(result.current.isPlaceholderData).toEqual(true)
      expect(result.current.data).toEqual(member)
    })
  })
})
