import { MemberFields } from '@tribeplatform/gql-client'
import { Member, QueryMemberArgs } from '@tribeplatform/gql-client/types'

import { useQuery, UseQueryOptions } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getMemberKey } from '../../utils/keys'
import { useCachedMember } from '../cache'

export const useMember = (options: {
  variables: QueryMemberArgs
  fields?: MemberFields
  useQueryOptions?: UseQueryOptions<Member>
}) => {
  const { variables, fields = 'default', useQueryOptions } = options
  const { client } = useTribeClient()
  const memberKey = getMemberKey({ variables, fields })
  const memberPlaceHolder = useCachedMember(variables?.id)

  return useQuery<Member>(
    memberKey,
    () => client.members.get(variables, fields),
    {
      placeholderData: () => memberPlaceHolder,
      ...useQueryOptions,
    },
  )
}
