import { Action } from '@tribeplatform/gql-client/types'

import { useMutation, UseMutationOptions, useQueryClient } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getAuthTokenKey } from '../../utils/keys'
import { getNetworkKey } from '../../utils/keys/network.key'

export const useClearNewDomain = (options?: {
  useMutationOptions?: UseMutationOptions<Action, Error>
}) => {
  const { useMutationOptions } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()

  return useMutation<Action, Error>(() => client.network.clearNewDomain(), {
    onSettled: () => {
      const authTokenKey = getAuthTokenKey()
      const networkKey = getNetworkKey()
      queryClient.invalidateQueries(authTokenKey)
      queryClient.invalidateQueries(networkKey)
    },
    ...useMutationOptions,
  })
}
