import { NetworkFields } from '@tribeplatform/gql-client'
import {
  Network,
  MutationDeleteMemberSchemaFieldArgs,
  AuthToken,
} from '@tribeplatform/gql-client/types'
import { useQueryClient } from '@tribeplatform/react-sdk/lib'

import { useMutation, UseMutationOptions } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getAuthTokenKey } from '../../utils/keys/authToken.keys'
import { getNetworkKey } from '../../utils/keys/network.key'

export const useDeleteMemberSchemaField = (options?: {
  fields?: NetworkFields
  useMutationOptions?: UseMutationOptions<
    Network,
    Error,
    MutationDeleteMemberSchemaFieldArgs
  >
}) => {
  const { useMutationOptions, fields = 'default' } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()
  const networkKey = getNetworkKey()
  const authTokenKey = getAuthTokenKey()

  return useMutation<Network, Error, MutationDeleteMemberSchemaFieldArgs>(
    input => client.network.deleteMemberSchemaField(input, fields),
    {
      onMutate: variables => {
        queryClient.setQueriesData<AuthToken>(authTokenKey, old => ({
          ...old,
          network: {
            ...old?.network,
            memberFields: {
              fields: old?.network?.memberFields?.fields?.filter(
                field => field.key !== variables.key,
              ),
            },
          },
        }))
        queryClient.setQueriesData<Network>(networkKey, old => ({
          ...old,
          memberFields: {
            fields: old?.memberFields?.fields?.filter(
              field => field.key !== variables.key,
            ),
          },
        }))
      },
      onSettled: () => {
        queryClient.invalidateQueries(networkKey)
        queryClient.invalidateQueries(authTokenKey)
      },
      ...useMutationOptions,
    },
  )
}
