import { NetworkFields } from '@tribeplatform/gql-client'
import {
  Network,
  MutationReorderMemberSchemaFieldsArgs,
} from '@tribeplatform/gql-client/types'
import { useQueryClient } from '@tribeplatform/react-sdk/lib'

import { useMutation, UseMutationOptions } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getAuthTokenKey } from '../../utils/keys/authToken.keys'
import { getNetworkKey } from '../../utils/keys/network.key'

export const useReorderMemberSchemaFields = (options?: {
  fields?: NetworkFields
  useMutationOptions?: UseMutationOptions<
    Network,
    Error,
    MutationReorderMemberSchemaFieldsArgs
  >
}) => {
  const { useMutationOptions, fields = 'default' } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()
  const networkKey = getNetworkKey()
  const authTokenKey = getAuthTokenKey()

  return useMutation<Network, Error, MutationReorderMemberSchemaFieldsArgs>(
    input => client.network.reorderMemberSchemaFields(input, fields),
    {
      onSettled: () => {
        queryClient.invalidateQueries(networkKey)
        queryClient.invalidateQueries(authTokenKey)
      },
      ...useMutationOptions,
    },
  )
}
