import { NetworkFields } from '@tribeplatform/gql-client'
import {
  Network,
  MutationArchiveMemberSchemaFieldArgs,
  AuthToken,
} from '@tribeplatform/gql-client/types'
import { useQueryClient } from '@tribeplatform/react-sdk/lib'

import { useMutation, UseMutationOptions } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getAuthTokenKey } from '../../utils/keys/authToken.keys'
import { getNetworkKey } from '../../utils/keys/network.key'

export const useUnArchiveMemberSchemaField = (options?: {
  fields?: NetworkFields
  useMutationOptions?: UseMutationOptions<
    Network,
    Error,
    MutationArchiveMemberSchemaFieldArgs
  >
}) => {
  const { useMutationOptions, fields = 'default' } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()
  const networkKey = getNetworkKey()
  const authTokenKey = getAuthTokenKey()

  return useMutation<Network, Error, MutationArchiveMemberSchemaFieldArgs>(
    input => client.network.unArchiveMemberSchemaField(input, fields),
    {
      onMutate: variables => {
        queryClient.cancelQueries(networkKey)
        queryClient.cancelQueries(authTokenKey)

        queryClient.setQueriesData<AuthToken>(authTokenKey, old => ({
          ...old,
          network: {
            ...old?.network,
            memberFields: {
              fields: old?.network?.memberFields?.fields?.map(field => ({
                ...field,
                archived:
                  field?.key === variables?.key ? false : field?.archived,
              })),
            },
          },
        }))
        queryClient.setQueriesData<Network>(networkKey, old => ({
          ...old,
          memberFields: {
            fields: old?.memberFields?.fields?.map(field => ({
              ...field,
              archived: field?.key === variables?.key ? false : field?.archived,
            })),
          },
        }))
      },
      onSettled: () => {
        queryClient.invalidateQueries(networkKey)
        queryClient.invalidateQueries(authTokenKey)
      },
      ...useMutationOptions,
    },
  )
}
