import { NetworkFields } from '@tribeplatform/gql-client'
import {
  Network,
  MutationUpdateMemberSchemaFieldArgs,
} from '@tribeplatform/gql-client/types'
import { useQueryClient } from '@tribeplatform/react-sdk/lib'

import { useMutation, UseMutationOptions } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getAuthTokenKey } from '../../utils/keys/authToken.keys'
import { getNetworkKey } from '../../utils/keys/network.key'

export const useUpdateMemberSchemaField = (options?: {
  fields?: NetworkFields
  useMutationOptions?: UseMutationOptions<
    Network,
    Error,
    MutationUpdateMemberSchemaFieldArgs
  >
}) => {
  const { useMutationOptions, fields = 'default' } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()
  const networkKey = getNetworkKey()
  const authTokenKey = getAuthTokenKey()

  return useMutation<Network, Error, MutationUpdateMemberSchemaFieldArgs>(
    input => client.network.updateMemberSchemaField(input, fields),
    {
      ...useMutationOptions,
      ...{
        onSettled: () => {
          queryClient.invalidateQueries(networkKey)
          queryClient.invalidateQueries(authTokenKey)
        },
      },
    },
  )
}
