import { NotificationFields } from '@tribeplatform/gql-client'
import {
  PaginatedNotification,
  QueryNotificationsArgs,
} from '@tribeplatform/gql-client/types'

import { useInfiniteQuery, UseInfiniteQueryOptions } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getNotificationsKey } from '../../utils/keys'

export const DefaultNotificationLimit = 10

export const useNotifications = (options: {
  variables: QueryNotificationsArgs
  fields?: NotificationFields
  useInfiniteQueryOptions?: UseInfiniteQueryOptions<PaginatedNotification>
}) => {
  const {
    variables = { limit: DefaultNotificationLimit },
    fields = {
      target: { media: 'basic' },
      space: 'basic',
      actor: { media: 'basic' },
      object: {
        media: 'basic',
      },
    },
    useInfiniteQueryOptions,
  } = options || {}

  const { client } = useTribeClient()
  const notificationsKey = getNotificationsKey({ variables, fields })

  return useInfiniteQuery<PaginatedNotification>(
    notificationsKey,
    ({ pageParam: after }) =>
      client?.notifications.list(
        {
          after,
          ...variables,
        },
        fields,
      ),
    useInfiniteQueryOptions,
  )
}
