import { ClientError } from '@tribeplatform/gql-client'
import {
  SpaceDefaultNotificationSettings,
  MutationUpdateSpaceDefaultNotificationSettingsArgs,
} from '@tribeplatform/gql-client/types'

import { useMutation, UseMutationOptions, useQueryClient } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getSpaceDefaultNotificationSettingsKey } from '../../utils/keys'

export const useUpdateDefaultSpaceNotificationSettings = (options?: {
  useMutationOptions?: UseMutationOptions<
    SpaceDefaultNotificationSettings,
    ClientError,
    MutationUpdateSpaceDefaultNotificationSettingsArgs
  >
}) => {
  const { useMutationOptions } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()
  const spaceDefaultNotificationSettingsKey =
    getSpaceDefaultNotificationSettingsKey()

  return useMutation<
    SpaceDefaultNotificationSettings,
    ClientError,
    MutationUpdateSpaceDefaultNotificationSettingsArgs
  >(
    variables =>
      client.notifications.updateSpaceDefaultNotificationSettings(variables),
    {
      onSettled: () => {
        // invalidate to refetch again
        queryClient.invalidateQueries(spaceDefaultNotificationSettingsKey)
      },
      ...useMutationOptions,
    },
  )
}
