import { ClientError } from '@tribeplatform/gql-client'
import {
  MutationUpdateNetworkNotificationSettingsArgs,
  Network,
  NotificationNetworkSettings,
} from '@tribeplatform/gql-client/types'
import { useCachedNetwork } from '@tribeplatform/react-sdk/hooks'

import { useMutation, UseMutationOptions, useQueryClient } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getNetworkKey } from '../../utils/keys'

export const useUpdateNetworkNotificationSettings = (options?: {
  useMutationOptions?: UseMutationOptions<
    NotificationNetworkSettings,
    ClientError,
    MutationUpdateNetworkNotificationSettingsArgs,
    { snapshot: Network }
  >
}) => {
  const { useMutationOptions } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()
  const networkKey = getNetworkKey()
  const networkSnapshot = useCachedNetwork()

  return useMutation<
    NotificationNetworkSettings,
    ClientError,
    MutationUpdateNetworkNotificationSettingsArgs,
    { snapshot: Network }
  >(
    variables =>
      client.notifications.updateNetworkNotificationSettings(variables),
    {
      onMutate: async newNetworkSettings => {
        await queryClient.cancelQueries(networkKey)

        const snapshot = networkSnapshot

        queryClient.setQueriesData<Network>(networkKey, old => {
          return {
            ...old,
            settings: {
              ...old.settings,
              ...{
                emailEnabled:
                  newNetworkSettings?.input?.emailEnabled ??
                  old?.settings?.emailEnabled,
                emailNotificationEnabled:
                  newNetworkSettings?.input?.emailNotificationEnabled ??
                  old?.settings?.emailNotificationEnabled,
                emailFrom:
                  newNetworkSettings?.input?.emailFrom ??
                  old?.settings?.emailFrom,
              },
            },
          }
        })

        return { snapshot }
      },
      onError: (err, newNetworkSettings, context) => {
        // revert back the optimistic response
        queryClient.setQueriesData<Network>(networkKey, context.snapshot)
      },
      onSettled: () => {
        // invalidate to refetch again
        queryClient.invalidateQueries(networkKey)
      },
      ...useMutationOptions,
    },
  )
}
