import { ClientError, PostFields } from '@tribeplatform/gql-client'
import { Post, MutationMovePostArgs } from '@tribeplatform/gql-client/types'

import { useMutation, UseMutationOptions, useQueryClient } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getFeedKey, getPostKey, getPostsKey } from '../../utils/keys'
import { pinnedPostsFilter } from './filters'

export const useMovePost = (options?: {
  fields?: PostFields
  useMutationOptions?: UseMutationOptions<
    Post,
    ClientError,
    MutationMovePostArgs
  >
}) => {
  const { useMutationOptions, fields } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()

  return useMutation<Post, ClientError, MutationMovePostArgs>(
    variables => client.posts.movePost(variables, fields),
    {
      onSettled: (data, error, variables) => {
        const postKey = getPostKey({ variables: { id: variables.id } })
        queryClient.invalidateQueries(postKey)

        const postsKey = getPostsKey()
        queryClient.invalidateQueries(postsKey)
        queryClient.invalidateQueries({ ...pinnedPostsFilter, active: true })

        const feedKey = getFeedKey()
        queryClient.invalidateQueries(feedKey)
      },
      ...useMutationOptions,
    },
  )
}
