import { ClientError, PostFields } from '@tribeplatform/gql-client'
import { Post, MutationMovePostsArgs } from '@tribeplatform/gql-client/types'

import { useMutation, UseMutationOptions, useQueryClient } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getFeedKey, getPostKey, getPostsKey } from '../../utils/keys'
import { pinnedPostsFilter } from './filters'

export const useMovePosts = (options?: {
  fields?: PostFields
  useMutationOptions?: UseMutationOptions<
    Post[],
    ClientError,
    MutationMovePostsArgs
  >
}) => {
  const { useMutationOptions, fields } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()

  return useMutation<Post[], ClientError, MutationMovePostsArgs>(
    variables => client.posts.movePosts(variables, fields),
    {
      onSettled: (data, error, variables) => {
        variables?.ids?.forEach(id => {
          const postKey = getPostKey({ variables: { id } })
          queryClient.invalidateQueries(postKey)
        })

        const postsKey = getPostsKey()
        queryClient.invalidateQueries(postsKey)
        queryClient.invalidateQueries({ ...pinnedPostsFilter, active: true })

        const feedKey = getFeedKey()
        queryClient.invalidateQueries(feedKey)
      },
      ...useMutationOptions,
    },
  )
}
