import { InfiniteData } from 'react-query'

import { ClientError } from '@tribeplatform/gql-client'
import {
  Action,
  MutationRemoveSpaceMembersArgs,
  PaginatedSpaceMember,
} from '@tribeplatform/gql-client/types'

import { useMutation, UseMutationOptions, useQueryClient } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getSpaceMembersKey } from '../../utils/keys'

export const useRemoveSpaceMember = (options?: {
  useMutationOptions?: UseMutationOptions<
    Action,
    ClientError,
    MutationRemoveSpaceMembersArgs
  >
}) => {
  const { useMutationOptions } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()

  return useMutation<Action, ClientError, MutationRemoveSpaceMembersArgs>(
    input => client.spaceMembers.remove(input),
    {
      onMutate: variables => {
        const spaceMembersKey = getSpaceMembersKey({
          variables: {
            spaceId: variables.spaceId,
          },
        })

        queryClient.setQueriesData<InfiniteData<PaginatedSpaceMember>>(
          spaceMembersKey,
          old => ({
            ...old,
            pages: old?.pages?.map(page => ({
              ...page,
              edges: page?.edges?.filter(
                edge => !variables?.memberIds?.includes(edge?.node?.member?.id),
              ),
            })),
          }),
        )
      },
      onSettled: (data, error, variables) => {
        const spaceMembersKey = getSpaceMembersKey({
          variables: {
            spaceId: variables.spaceId,
          },
        })
        queryClient.invalidateQueries(spaceMembersKey)
      },
      ...useMutationOptions,
    },
  )
}
