import { ClientError } from '@tribeplatform/gql-client'
import {
  Action,
  MutationUpdateMemberSpaceRoleArgs,
} from '@tribeplatform/gql-client/types'

import { useMutation, UseMutationOptions, useQueryClient } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getSpaceMembersKey } from '../../utils/keys'

export const useUpdateMemberSpaceRole = (options?: {
  useMutationOptions?: UseMutationOptions<
    Action,
    ClientError,
    MutationUpdateMemberSpaceRoleArgs
  >
}) => {
  const { useMutationOptions } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()

  return useMutation<Action, ClientError, MutationUpdateMemberSpaceRoleArgs>(
    input => client.spaceRoles.updateMemberRole(input),
    {
      onSettled: (data, error, variables) => {
        const spaceMembersKey = getSpaceMembersKey({
          variables: {
            spaceId: variables.spaceId,
          },
        })
        queryClient.invalidateQueries(spaceMembersKey)
      },
      ...useMutationOptions,
    },
  )
}
