import { SpaceFields } from '@tribeplatform/gql-client'
import { MutationCreateSpaceArgs, Space } from '@tribeplatform/gql-client/types'

import { useMutation, UseMutationOptions, useQueryClient } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import {
  getCollectionsKey,
  getSpaceKey,
  getMemberNotificationSettingsKey,
} from '../../utils/keys'

export const useCreateSpace = (options?: {
  fields?: SpaceFields
  useMutationOptions?: UseMutationOptions<
    Space,
    Error,
    MutationCreateSpaceArgs,
    { snapshot: Space }
  >
}) => {
  const { useMutationOptions, fields = 'default' } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()

  const collectionsKey = getCollectionsKey()

  return useMutation<
    Space,
    Error,
    MutationCreateSpaceArgs,
    { snapshot: Space }
  >((input: MutationCreateSpaceArgs) => client.spaces.create(input, fields), {
    onSuccess: async space => {
      const spaceKey = getSpaceKey({ variables: { id: space.id } })

      queryClient.setQueryData<Space>(spaceKey, _ => space)
      queryClient.invalidateQueries(getMemberNotificationSettingsKey())
      queryClient.invalidateQueries(spaceKey)
      queryClient.invalidateQueries(collectionsKey)
    },
    ...useMutationOptions,
  })
}
