import { ActionFields } from '@tribeplatform/gql-client/graphql'
import {
  Action,
  MutationDeleteSpaceArgs,
} from '@tribeplatform/gql-client/types'

import { useMutation, UseMutationOptions, useQueryClient } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import {
  getCollectionsKey,
  getMemberNotificationSettingsKey,
  getSpacesKey,
} from '../../utils/keys'

export const useDeleteSpace = (options?: {
  fields?: ActionFields
  useMutationOptions?: UseMutationOptions<
    Action,
    Error,
    MutationDeleteSpaceArgs
  >
}) => {
  const { useMutationOptions, fields = 'basic' } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()

  const collectionsKey = getCollectionsKey()
  const spacesKey = getSpacesKey()
  const memberNotificationSettingsKey = getMemberNotificationSettingsKey()

  return useMutation<Action, Error, MutationDeleteSpaceArgs>(
    input => client.spaces.delete(input, fields),
    {
      onSuccess: () => {
        queryClient.invalidateQueries(memberNotificationSettingsKey)
        queryClient.invalidateQueries(spacesKey)
        queryClient.invalidateQueries(collectionsKey)
      },
      ...useMutationOptions,
    },
  )
}
