import { ClientError } from '@tribeplatform/gql-client'
import {
  Action,
  MutationDeleteSpacePostTypesArgs,
} from '@tribeplatform/gql-client/types'

import { useMutation, UseMutationOptions, useQueryClient } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getSpacePostTypesKey } from '../../utils/keys'

export const useDeleteSpacePostTypes = (options?: {
  useMutationOptions?: UseMutationOptions<
    Action,
    ClientError,
    MutationDeleteSpacePostTypesArgs
  >
}) => {
  const { useMutationOptions } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()

  return useMutation<Action, ClientError, MutationDeleteSpacePostTypesArgs>(
    input => client.spacePostType.delete(input),
    {
      onSettled: () => {
        const spacePostTypeKey = getSpacePostTypesKey()
        queryClient.invalidateQueries(spacePostTypeKey)
      },
      ...useMutationOptions,
    },
  )
}
