import { ClientError } from '@tribeplatform/gql-client'
import { MutationJoinSpaceArgs, Action } from '@tribeplatform/gql-client/types'

import { useMutation, UseMutationOptions, useQueryClient } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import {
  getMemberNotificationSettingsKey,
  getPostsKey,
  getSpaceKey,
} from '../../utils/keys'

export const useJoinSpace = (options?: {
  useMutationOptions?: UseMutationOptions<
    Action,
    ClientError,
    MutationJoinSpaceArgs
  >
}) => {
  const { useMutationOptions } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()

  return useMutation<Action, ClientError, MutationJoinSpaceArgs>(
    (input: MutationJoinSpaceArgs) => client.spaces.join(input),
    {
      onSettled: (data, error, variables) => {
        queryClient.invalidateQueries(
          getSpaceKey({ variables: { id: variables.spaceId } }),
        )
        queryClient.invalidateQueries(getMemberNotificationSettingsKey())
        queryClient.invalidateQueries(getPostsKey())
      },
      ...useMutationOptions,
    },
  )
}
