import { SpaceMemberFields } from '@tribeplatform/gql-client/graphql'
import {
  QueryMemberSpacesArgs,
  PaginatedSpaceMember,
} from '@tribeplatform/gql-client/types'

import {
  UseInfiniteQueryOptions,
  useInfiniteQuery,
} from '../../lib/react-query/useInfiniteQuery'
import { useTribeClient } from '../../useTribeClient'
import { getMemberSpacesKey } from '../../utils/keys'

export const useMemberSpaces = (options?: {
  variables?: QueryMemberSpacesArgs
  fields?: SpaceMemberFields
  useInfiniteQueryOptions?: UseInfiniteQueryOptions<PaginatedSpaceMember>
}) => {
  const {
    variables,
    fields = { space: 'basic', member: 'basic', role: 'basic' },
    useInfiniteQueryOptions,
  } = options || {}
  const { client } = useTribeClient()
  const memberSpacesKey = getMemberSpacesKey({ variables, fields })

  return useInfiniteQuery<PaginatedSpaceMember>(
    memberSpacesKey,
    ({ pageParam: after }) =>
      client?.spaceMembers.listSpaces({ after, ...variables }, fields),
    useInfiniteQueryOptions,
  )
}
