import { SpaceFields } from '@tribeplatform/gql-client'
import {
  PaginatedSpace,
  QuerySpacesArgs,
} from '@tribeplatform/gql-client/types'

import { UseInfiniteQueryOptions, useInfiniteQuery } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getSpacesKey } from '../../utils/keys'

export const DefaultSpacesLimit = 10

export const useSpaces = (options?: {
  variables?: QuerySpacesArgs
  fields?: SpaceFields
  useInfiniteQueryOptions?: UseInfiniteQueryOptions<PaginatedSpace>
}) => {
  const {
    variables = { limit: DefaultSpacesLimit },
    fields = 'basic',
    useInfiniteQueryOptions,
  } = options || {}
  const { client } = useTribeClient()
  const spacesKey = getSpacesKey({ variables, fields })

  return useInfiniteQuery<PaginatedSpace>(
    spacesKey,
    ({ pageParam: after }) =>
      client?.spaces.list({ after, ...variables }, fields),
    useInfiniteQueryOptions,
  )
}
