import { SpaceFields } from '@tribeplatform/gql-client'
import { QuerySpacesByIdsArgs, Space } from '@tribeplatform/gql-client/types'

import { useQuery, UseQueryOptions } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getSpacesByIdsKey } from '../../utils/keys'
import { useCachedSpaces } from '../cache/useCachedSpace'

export const useSpacesByIds = (options?: {
  variables: QuerySpacesByIdsArgs
  fields?: SpaceFields
  useQueryOptions?: UseQueryOptions<Space[]>
}) => {
  const { variables, fields = 'basic', useQueryOptions } = options || {}
  const { client } = useTribeClient()
  const cachedSpaces = useCachedSpaces(variables.ids.map(id => ({ id })))
  const spacesByIdsKey = getSpacesByIdsKey({ variables, fields })

  return useQuery<Space[]>(
    spacesByIdsKey,
    () => client?.spaces.listByIds(variables, fields),
    { placeholderData: () => cachedSpaces, ...useQueryOptions },
  )
}
