import { SpaceFields } from '@tribeplatform/gql-client'
import { QuerySpacesBySlugsArgs, Space } from '@tribeplatform/gql-client/types'

import { useQuery, UseQueryOptions } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getSpacesBySlugsKey } from '../../utils/keys'
import { useCachedSpaces } from '../cache/useCachedSpace'

export const useSpacesBySlugs = (options?: {
  variables: QuerySpacesBySlugsArgs
  fields?: SpaceFields
  useQueryOptions?: UseQueryOptions<Space[]>
}) => {
  const { variables, fields = 'basic', useQueryOptions } = options || {}
  const { client } = useTribeClient()
  const cachedSpaces = useCachedSpaces(variables.slugs.map(slug => ({ slug })))
  const spacesBySlugsKey = getSpacesBySlugsKey({ variables, fields })

  return useQuery<Space[]>(
    spacesBySlugsKey,
    () => client?.spaces.listBySlugs(variables, fields),
    { placeholderData: () => cachedSpaces, ...useQueryOptions },
  )
}
