import { ClientError, SpacePostTypeFields } from '@tribeplatform/gql-client'
import {
  MutationUpdateSpacePostTypesArgs,
  SpacePostType,
} from '@tribeplatform/gql-client/types'

import { useMutation, UseMutationOptions, useQueryClient } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getSpacePostTypeKey, getSpacePostTypesKey } from '../../utils/keys'

export const useUpdateSpacePostTypes = (options?: {
  fields?: SpacePostTypeFields
  useMutationOptions?: UseMutationOptions<
    Array<SpacePostType>,
    ClientError,
    MutationUpdateSpacePostTypesArgs,
    { snapshot: Array<SpacePostType> }
  >
}) => {
  const { useMutationOptions, fields = 'basic' } = options || {}
  const { client } = useTribeClient()
  const queryClient = useQueryClient()

  return useMutation<
    Array<SpacePostType>,
    ClientError,
    MutationUpdateSpacePostTypesArgs,
    { snapshot: Array<SpacePostType> }
  >(
    (input: MutationUpdateSpacePostTypesArgs) =>
      client.spacePostType.update(input, fields),
    {
      onSettled: (data, error, variables) => {
        const spacePostTypesKey = getSpacePostTypesKey({
          variables: {
            spaceId: variables?.spaceId,
          },
        })
        queryClient.invalidateQueries(spacePostTypesKey)

        const spacePostTypeKey = getSpacePostTypeKey({
          variables: {
            spaceId: variables?.spaceId,
          },
        })
        queryClient.invalidateQueries(spacePostTypeKey)
      },
      ...useMutationOptions,
    },
  )
}
