import { TemplateFields } from '@tribeplatform/gql-client'
import {
  PaginatedTemplate,
  QueryTemplatesArgs,
} from '@tribeplatform/gql-client/types'

import { useInfiniteQuery, UseInfiniteQueryOptions } from '../../lib'
import { useTribeClient } from '../../useTribeClient'
import { getTemplatesKey } from '../../utils/keys'

export const DefaultTemplatesLimit = 10

export const useTemplates = (options?: {
  variables?: QueryTemplatesArgs
  fields?: TemplateFields
  useInfiniteQueryOptions?: UseInfiniteQueryOptions<PaginatedTemplate>
}) => {
  const {
    variables = { limit: DefaultTemplatesLimit },
    fields = 'basic',
    useInfiniteQueryOptions,
  } = options || {}
  const { client } = useTribeClient()
  const templatesKey = getTemplatesKey({ variables, fields })

  return useInfiniteQuery<PaginatedTemplate>(
    templatesKey,
    ({ pageParam: after }) =>
      client?.templates.list({ after, ...variables }, fields),
    useInfiniteQueryOptions,
  )
}
