/* eslint-disable no-process-env */
/* eslint-disable global-require */

const colors = require('tailwindcss/colors')

const withOpacityValue =
  variable =>
  ({ opacityValue }) => {
    if (opacityValue === undefined) {
      return `rgb(var(${variable}))`
    }
    return `rgb(var(${variable}) / ${opacityValue})`
  }

const createColorRange = name => ({
  50: withOpacityValue(`--tribe-color-${name}-50`),
  100: withOpacityValue(`--tribe-color-${name}-100`),
  200: withOpacityValue(`--tribe-color-${name}-200`),
  300: withOpacityValue(`--tribe-color-${name}-300`),
  400: withOpacityValue(`--tribe-color-${name}-400`),
  500: withOpacityValue(`--tribe-color-${name}-500`),
  600: withOpacityValue(`--tribe-color-${name}-600`),
  700: withOpacityValue(`--tribe-color-${name}-700`),
  800: withOpacityValue(`--tribe-color-${name}-800`),
  900: withOpacityValue(`--tribe-color-${name}-900`),
  DEFAULT: withOpacityValue(`--tribe-color-${name}-500`),
})

const createColor = name => ({
  [name]: createColorRange(name),
})

const isProd = process.env.NODE_ENV === 'production'

module.exports = {
  mode: isProd ? '' : 'jit',
  content: ['./src/**/*.tsx', './src/**/*.ts'],
  theme: {
    colors: {
      transparent: 'transparent',
      current: 'currentColor',
      white: colors.white,
      black: colors.black,
      gray: colors.gray,
      red: colors.red,
      yellow: colors.amber,
      green: colors.emerald,
      blue: colors.blue,
      indigo: colors.indigo,
      purple: colors.violet,
      pink: colors.pink,
      ...createColor('main'),
      ...createColor('surface'),
      ...createColor('actionPrimary'),
      ...createColor('actionSecondary'),
      ...createColor('actionAccent'),
      ...createColor('actionAccentHover'),
      ...createColor('basicMain'),
      ...createColor('basicSurface'),
      ...createColor('basicPrimary'),
      ...createColor('basicSecondary'),
      ...createColor('success'),
      ...createColor('danger'),
      ...createColor('warning'),
      ...createColor('info'),
    },
    extend: {
      maxWidth: {
        '8xl': '84rem',
      },
      ringOffsetWidth: {
        DEFAULT: '2px',
      },
      ringWidth: {
        DEFAULT: '2px',
      },
      ringOpacity: {
        DEFAULT: '1',
      },
    },
  },
  plugins: [require('@tailwindcss/forms')],
  corePlugins: {
    preflight: false,
  },
}
