import { ReactNode } from 'react'

import { renderHook, RenderHookOptions } from '@testing-library/react-hooks'
import merge from 'lodash.merge'
import { Hydrate } from 'react-query'

import { jwt } from '@tribeplatform/test-utils/factory'

import { Provider, ProviderProps } from '../src'

export function createWrapper({
  queryConfig,
  dehydratedState,
}: {
  queryConfig?: ProviderProps['queryConfig']
  dehydratedState?: unknown
}) {
  const config = {
    baseUrl: 'http://localhost/graphql',
    networkDomain: '',
    accessToken: jwt(),
  }
  const defaultQueryConfig = {
    defaultOptions: {
      queries: {
        retry: false,
        staleTime: Infinity,
        cacheTime: Infinity,
      },
    },
    ...queryConfig,
  }

  return ({ children }: { children?: ReactNode }) => (
    <Provider
      config={config}
      queryConfig={merge(defaultQueryConfig, queryConfig)}
    >
      <Hydrate state={dehydratedState}>{children}</Hydrate>
    </Provider>
  )
}

const customRenderHook = <TProps, TResult>(
  callback: (props: TProps) => TResult,
  options?: RenderHookOptions<TProps> &
    ProviderProps['queryConfig'] & { dehydratedState: unknown },
) => {
  const { queryCache, dehydratedState, ...rest } = options || {}

  return renderHook(callback, {
    wrapper: createWrapper({ queryConfig: { queryCache }, dehydratedState }),
    ...rest,
  })
}
export { customRenderHook as renderHook }
